@@ -2,10 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_groups.pl,v 1.10 2004/10/16 10:24:09 yeupou Exp $
+# $Id: sv_groups.pl,v 1.13 2005/03/21 07:04:45 yeupou Exp $
 #
-#  Copyright 2001      (c) Loic Dachary <loic--at--gnu.org> (sv_cvs.pl)
-#            2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
+#  Copyright 2001-2005 (c) Loic Dachary <loic--gnu.org> (sv_cvs.pl)
+#                          Mathieu Roy <yeupou--gnu.org> 
+#                          Sylvain Beucler <beuc--beuc.net>
+#                          Timothee Besset <ttimo--ttimo.net>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -48,12 +50,14 @@ use strict;
 use Savannah;
 use Savannah::Download;
 use Savannah::Cvs;
+use Savannah::Svn;
 use Getopt::Long;
 use Term::ANSIColor qw(:constants);
 use POSIX qw(strftime);
 
 # Import
 our $sys_cron_groups;
+our $use_svn;
 
 my $script = "sv_groups";
 my $logfile = "/var/log/sv_database2system.log";
@@ -66,16 +70,25 @@ my $version = GetVersion();
 
 my $no_etc = 0;
 my $no_cvs = 0; 
+my $no_arch = 0; 
+my $no_svn = 0;
 my $no_homepage = 0;
 my $no_download = 0;
 
+my $only_etc;
+my $only_cvs;
+my $only_arch;
+my $only_svn;
+my $only_homepage;
+my $only_download;
+
 # deprecated, replaced by webgroup
 my $one_group = 0;
 my $webgroup = 0;
 
 my $min_gid = "5000";
 
-my $subversions = AreWeOnSubversions();
+#my $subversions = AreWeOnSubversions();
 
 # get options
 eval {
@@ -84,15 +97,23 @@ eval {
 			 "debug" => \$debug,
 			 "no-etc" => \$no_etc,
 			 "no-cvs" => \$no_cvs,
+			 "no-svn" => \$no_svn,
+			 "no-arch" => \$no_arch,
 			 "no-homepage" => \$no_homepage,
 			 "no-download" => \$no_download,
+			 "only-etc" => \$only_etc,
+			 "only-cvs" => \$only_cvs,
+			 "only-svn" => \$only_svn,
+			 "only-arch" => \$only_arch,
+			 "only-homepage" => \$only_homepage,
+			 "only-download" => \$only_download,
 			 "webgroup" => \$webgroup,
 			 "one-group" => \$one_group);
 };
 
 if($help) {
     print STDERR <<EOF;
-Usage: $0 [project] [OPTIONS] 
+Usage: $0 [OPTIONS] 
 
 Update the system to reflect the database, about groups.
 Normally, sv_users should run just after.
@@ -101,11 +122,21 @@ Normally, sv_users should run just after.
   -d, --debug                  Do nothing, print everything
       --cron                   Option to set when including this script
                                in a crontab
+
       --no-etc                 Do not update system groups
       --no-cvs                 Do not update cvs trees
+      --no-arch                Do not update arch trees
+      --no-svn                 Do not update svn trees
       --no-homepage            Do not update homepage dirs
       --no-download            Do not update download dirs
 
+      --only-etc               Only update system groups
+      --only-cvs               Only update cvs trees
+      --only-arch              Only update arch trees
+      --only-svn               Only update svn trees
+      --only-homepage          Only update homepage dirs
+      --only-download          Only update download dirs
+
       --webgroup               For each projects, add users in two group,
                                including one with the prefix web.
                                (this was the default behavior in =< 1.0.4)
@@ -115,6 +146,31 @@ EOF
 exit(1);
 }
 
+# If we are asked to create only a few services, set everything to "no"
+# and later add the only one(s) asked for.
+if ($only_etc ||
+    $only_cvs ||
+    $only_arch ||
+    $only_svn ||
+    $only_homepage ||
+    $only_download) {
+ 
+    
+    $no_etc = 1;
+    $no_cvs = 1;
+    $no_arch = 1;
+    $no_svn = 1;
+    $no_homepage = 1;
+    $no_download = 1;
+
+    $no_etc = 0 if $only_etc;
+    $no_cvs = 0 if $only_cvs;
+    $no_arch = 0 if $only_arch;
+    $no_svn = 0 if $only_svn;
+    $no_homepage = 0 if $only_homepage;
+    $no_download = 0 if $only_download;
+}
+
 # Test if we should run, according to conffile
 exit if ($cron && ! $sys_cron_groups);
 
@@ -129,7 +185,7 @@ if (-e $lockfile) {
     print LOG "[$script] There's a lock ($lockfile), exiting\n";
     die "There's a lock ($lockfile), exiting";
 }
-`touch $lockfile`;
+system("touch", $lockfile);
 
 
 #######################################################################
@@ -152,11 +208,11 @@ if (-e $lockfile) {
 my %db_group_type;
 foreach my $line (GetDB("group_type", 
 			0,
-			"name,type_id,dir_type_homepage,dir_type_cvs,dir_type_download,dir_homepage,dir_cvs,dir_download,can_use_homepage,can_use_cvs,can_use_download")) {
+			"name,type_id,dir_type_homepage,dir_type_cvs,dir_type_arch,dir_type_svn,dir_type_download,dir_homepage,dir_cvs,dir_arch,dir_svn,dir_download,can_use_homepage,can_use_cvs,can_use_arch,can_use_svn,can_use_download")) {
     chomp($line);
-    my ($name, $id, $dir_type_homepage, $dir_type_cvs, $dir_type_download, $dir_homepage, $dir_cvs, $dir_download, $can_use_homepage, $can_use_cvs, $can_use_download) = split(",", $line);
+    my ($name, $id, $dir_type_homepage, $dir_type_cvs, $dir_type_arch, $dir_type_svn, $dir_type_download, $dir_homepage, $dir_cvs, $dir_arch, $dir_svn, $dir_download, $can_use_homepage, $can_use_cvs, $can_use_arch, $can_use_svn, $can_use_download) = split(",", $line);
     print "DBG db: get $line from database\n" if $debug;
-    $db_group_type{$id} = [ ($name, $id, $dir_type_homepage, $dir_type_cvs, $dir_type_download, $dir_homepage, $dir_cvs, $dir_download, $can_use_homepage, $can_use_cvs, $can_use_download) ];
+    $db_group_type{$id} = [ ($name, $id, $dir_type_homepage, $dir_type_cvs, $dir_type_arch, $dir_type_svn, $dir_type_download, $dir_homepage, $dir_cvs, $dir_arch, $dir_svn, $dir_download, $can_use_homepage, $can_use_cvs, $can_use_arch, $can_use_svn, $can_use_download) ];
 }
 
 # db_groups:
@@ -174,11 +230,11 @@ my %db_groups;
 my @db_groups;
 foreach my $line (GetDB("groups", 
 			"status='A'",
-			"unix_group_name,type,is_public,use_homepage,use_cvs,use_download,dir_homepage,dir_cvs,dir_download")) {
+			"unix_group_name,type,is_public,use_homepage,use_cvs,use_arch,use_svn,use_download,dir_homepage,dir_cvs,dir_arch,dir_svn,dir_download")) {
     chomp($line);
-    my ($name, $type, $is_public, $use_homepage, $use_cvs, $use_download, $dir_homepage, $dir_cvs, $dir_download) = split(",", $line);
+    my ($name, $type, $is_public, $use_homepage, $use_cvs, $use_arch, $use_svn, $use_download, $dir_homepage, $dir_cvs, $dir_arch, $dir_svn, $dir_download) = split(",", $line);
     print "DBG db: get group $line from database\n" if $debug;
-    $db_groups{$name} = [ ($name, $type, $is_public, $use_homepage, $use_cvs, $use_download, $dir_homepage, $dir_cvs, $dir_download) ];
+    $db_groups{$name} = [ ($name, $type, $is_public, $use_homepage, $use_cvs, $use_arch, $use_svn, $use_download, $dir_homepage, $dir_cvs, $dir_arch, $dir_svn, $dir_download) ];
     push(@db_groups, $name);
 }
 
@@ -253,7 +309,7 @@ for ("svusers", "anoncvs") {
 
 foreach my $group (@only_in_db){
     
-    my ($name, $type, $is_public, $use_homepage, $use_cvs, $use_download) = @{$db_groups{$group}};
+    my ($name, $type, $is_public, $use_homepage, $use_cvs, $use_arch, $use_svn, $use_download) = @{$db_groups{$group}};
     
     print "DBG create: $name and web$name\n" if $debug;
     
@@ -292,21 +348,25 @@ foreach my $group (@db_groups) {
 
     } else {
 	
-	my ($name, $type, $is_public, $use_homepage, $use_cvs, $use_download, $group_dir_homepage, $group_dir_cvs, $group_dir_download) = @{$db_groups{$group}};
-	my ($type_name, $type_id, $dir_type_homepage, $dir_type_cvs, $dir_type_download, $dir_homepage, $dir_cvs, $dir_download, $can_use_homepage, $can_use_cvs, $can_use_download) = @{$db_group_type{$type}};
+	my ($name, $type, $is_public, $use_homepage, $use_cvs, $use_arch, $use_svn, $use_download, $group_dir_homepage, $group_dir_cvs, $group_dir_arch, $group_dir_svn, $group_dir_download) = @{$db_groups{$group}};
+	my ($type_name, $type_id, $dir_type_homepage, $dir_type_cvs, $dir_type_arch, $dir_type_svn, $dir_type_download, $dir_homepage, $dir_cvs, $dir_arch, $dir_svn, $dir_download, $can_use_homepage, $can_use_cvs, $can_use_arch, $can_use_svn, $can_use_download) = @{$db_group_type{$type}};
         
 	# If a use in the database is empty, set it to the group type can_use
 	$use_homepage = $can_use_homepage if $use_homepage eq '';
 	$use_cvs = $can_use_cvs if $use_cvs eq '';
+	$use_arch = $can_use_arch if $use_arch eq '';
+	$use_svn = $can_use_svn if $use_svn eq '';
 	$use_download = $can_use_download if $use_download eq '';
 	
 	# If a group_dir in the database is not empty, set reset the default
 	# (it means that the group does not respect the group type settings)
 	$dir_homepage = $group_dir_homepage if $group_dir_homepage;
 	$dir_cvs = $group_dir_cvs if $group_dir_cvs;
+	$dir_arch = $group_dir_arch if $group_dir_arch;
+	$dir_svn = $group_dir_svn if $group_dir_svn;
 	$dir_download = $group_dir_download if $group_dir_download;
 	
-	print "DBG update: $name, type:$type, public:$is_public, homepage:$use_homepage, cvs:$use_cvs, download:$use_download\n\t $dir_homepage $dir_cvs $dir_download\n" if $debug;
+	print "DBG update: $name, type:$type, public:$is_public, homepage:$use_homepage, cvs:$use_cvs, arch:$use_arch, svn:$use_svn, download:$use_download\n\t $dir_homepage $dir_cvs $dir_download\n" if $debug;
 	
 	my $madesomething;
 	
@@ -328,7 +388,11 @@ foreach my $group (@db_groups) {
 		    $madesomething .= DownloadMakeArea($name,$dir_cvs,$is_public); 
 		} elsif ($dir_type_cvs eq "cvsattic") {
 		    $madesomething .= CvsMakeAreaAttic($name,$dir_cvs,$is_public);
-		}
+		} elsif ($dir_type_cvs eq "savannah-gnu" or $dir_type_cvs eq "savannah-nongnu") {
+		    $madesomething .= CvsMakeAreaSavannah($name,$dir_cvs,$is_public);
+		} elsif ($dir_type_cvs eq "basicsvn") {
+		    $madesomething .= SvnMakeArea($name,$dir_cvs,$is_public);
+		}    
 	    }
 	    
 	    # Create the web area, by relying on the library, that should
@@ -341,6 +405,12 @@ foreach my $group (@db_groups) {
 		    $madesomething .= DownloadMakeArea($name,$dir_homepage,$is_public); 
 		} elsif ($dir_type_homepage eq "cvsattic") {
 		    $madesomething .= CvsMakeAreaAttic($name,$dir_homepage,$is_public);
+		} elsif ($dir_type_homepage eq "savannah-gnu") {
+		    $madesomething .= WebCvsMakeAreaSavannahGNU($name,$dir_homepage,$is_public);
+		} elsif ($dir_type_homepage eq "savannah-nongnu") {
+		    $madesomething .= WebCvsMakeAreaSavannahNonGNU($name,$dir_homepage,$is_public);
+		} elsif ($dir_type_homepage eq "basicsvn") {
+		    $madesomething .= SvnMakeArea($name,$dir_homepage,$is_public);
 		}    
 	    }
 	    
@@ -354,9 +424,46 @@ foreach my $group (@db_groups) {
 		    $madesomething .= DownloadMakeArea($name,$dir_download,$is_public); 
 		} elsif ($dir_type_download eq "cvsattic") {
 		    $madesomething .= CvsMakeAreaAttic($name,$dir_download,$is_public);
-		}      
+		} elsif ($dir_type_download eq "savannah-gnu" or $dir_type_download eq "savannah-nongnu") {
+		    $madesomething .= DownloadMakeAreaSavannah($name,$dir_download,$is_public);
+		} elsif ($dir_type_download eq "basicsvn") {
+		    $madesomething .= SvnMakeArea($name,$dir_download,$is_public);
+		}    
+	    }
+
+	    # Create the arch area, by relying on the library, that should
+	    # make the appropriate decision (ie if no %PROJECT string is
+	    # provided, nothing should be done)
+	    if ($use_arch && ! $no_arch) {
+		if ($dir_type_arch eq "basiccvs"){ 
+		    $madesomething .= CvsMakeArea($name,$dir_arch,$is_public); 
+		} elsif ($dir_type_arch eq "basicdirectory"){ 
+		    $madesomething .= DownloadMakeArea($name,$dir_arch,$is_public); 
+		} elsif ($dir_type_arch eq "cvsattic") {
+		    $madesomething .= CvsMakeAreaAttic($name,$dir_arch,$is_public);
+		} elsif ($dir_type_arch eq "savannah-gnu" or $dir_type_arch eq "savannah-nongnu") {
+		    $madesomething .= DownloadMakeAreaSavannah($name,$dir_arch,$is_public);
+		} elsif ($dir_type_arch eq "basicsvn") {
+		    $madesomething .= SvnMakeArea($name,$dir_arch,$is_public);
+		}  
+	    }
+
+	    # Create the svn area, by relying on the library, that should
+	    # make the appropriate decision (ie if no %PROJECT string is
+	    # provided, nothing should be done)
+	    if ($use_svn && !$no_svn) {
+		if ($dir_type_svn eq "basiccvs"){ 
+		    $madesomething .= CvsMakeArea($name,$dir_svn,$is_public); 
+		} elsif ($dir_type_svn eq "basicdirectory"){ 
+		    $madesomething .= DownloadMakeArea($name,$dir_svn,$is_public); 
+		} elsif ($dir_type_svn eq "cvsattic") {
+		    $madesomething .= CvsMakeAreaAttic($name,$dir_svn,$is_public);
+		} elsif ($dir_type_svn eq "savannah-gnu" or $dir_type_svn eq "savannah-nongnu") {
+		    $madesomething .= DownloadMakeAreaSavannah($name,$dir_svn,$is_public);
+		} elsif ($dir_type_svn eq "basicsvn") {
+		    $madesomething .= SvnMakeArea($name,$dir_svn,$is_public);
+		}
 	    }
-	    
 	}
 	
 	print LOG strftime "[$script] %c ---- update $name ($madesomething built)\n", localtime if $madesomething;
