@@ -2,10 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_users.pl,v 1.44 2004/10/19 12:30:00 yeupou Exp $
+# $Id: sv_users.pl,v 1.48 2005/03/20 11:47:20 yeupou Exp $
 #
-#  Copyright 2001      (c) Loic Dachary <loic--at--gnu.org> (sv_cvs.pl)
-#            2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
+#  Copyright 2001-2005 (c) Loic Dachary <loic--gnu.org> (sv_cvs.pl)
+#                          Mathieu Roy <yeupou--gnu.org> 
+#                          Sylvain Beucler <beuc--beuc.net>
+#                          Timothee Besset <ttimo--ttimo.net>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -64,6 +66,8 @@ my $usermod = "usermod";
 my $userdel = "userdel";
 my $userx_prefix;
 
+my $gpg_is_enabled = 0;
+
 my $min_uid = "5000";
 my $nobody_uid = "65534";
 
@@ -75,7 +79,7 @@ my $svusers = "svusers"; # this could be configurable, however it
                          # does not seems very important right now.
 my $svusers_gid = getgrnam($svusers);
 
-my $subversions = AreWeOnSubversions();
+#my $subversions = AreWeOnSubversions();
 
 # get options
 eval {
@@ -86,6 +90,7 @@ eval {
 			 "useradd=s" => \$useradd,
 			 "usermod=s" => \$usermod,
 			 "userdel=s" => \$userdel,
+			 "gpg" => \$gpg_is_enabled,
 			 "webgroup" => \$webgroup,
 			 "one-group" => \$one_group);
 };
@@ -110,6 +115,8 @@ Note that users are associated with the group $svusers.
       --usermod=[usermod]      Specify usermod binary
       --userdel=[userdel]      Specify userdel binary
 
+      --gpg                    Generate ~/.gnupg/pubring.gpg
+
       --webgroup               For each projects, add users in two group,
                                including one with the prefix web.
                                (this was the default behavior in =< 1.0.4)
@@ -184,15 +191,15 @@ foreach my $line (GetDB("user",
 #    We only consider active groups.
 #
 #    To limit the number of request, we use only one very long SQL request.
-my @www_groups;
-if ($subversions) { 
-    # sv.gnu.org specific, related to the special group www 
-    my @type1 = GetGroupList("type='1' AND status='A'", "unix_group_name");
-    my @type3 = GetGroupList("type='3' AND status='A'", "unix_group_name");
-    for (@type1, @type3) {
-	push(@www_groups, "web".$_);
-    }
-}
+#my @www_groups;
+#if ($subversions) { 
+#    # sv.gnu.org specific, related to the special group www 
+#    my @type1 = GetGroupList("type='1' AND status='A'", "unix_group_name");
+#    my @type3 = GetGroupList("type='3' AND status='A'", "unix_group_name");
+#    for (@type1, @type3) {
+#	push(@www_groups, "web".$_);
+#    }
+#}
 my %db_user_group;
 foreach my $line (GetDB("user_group,groups,user", 
 			"groups.group_id=user_group.group_id AND user.user_id=user_group.user_id AND groups.status='A' AND user_group.admin_flags<>'P'",
@@ -208,41 +215,21 @@ foreach my $line (GetDB("user_group,groups,user",
     # to allow him to edit files in CVSROOT. 
     # (yes, this group name is no longer pertinent)
     my ($u,$e,$r,$a,$g,$s,$un,$use_cvsadmin) = @{$db_user{$user}};
-
-# yeupou@gnu.org 2004-01-10
-# It is insecure to allow writing in CVSROOT
-#    if ($use_cvsadmin) {
-#	push(@groups, "anoncvs");
-#   }
-
-    unless ($group eq 'www' && $subversions) {
-	push(@groups, $group);
-	push(@groups, "web".$group) if $webgroup;
-    } else {
-	# www is a special group normally used to give
-	# a user write access on the whole CVSROOT of 
- 	# web area for any project of the group type 'www'
-	# This stuff is gnu.org specific. If it really need to
-	# be configurable (if someone want to use that), we'll
-	# think about make it configurable.
-	# For instance, we can imagine to select a box in the
-	# group type form.
-	
-	# Need to understand if we really want www + gnu types
-	# or only www.
-	@groups = (@groups, "www", @www_groups);
-	print "DBG db: $user is member of www !\n" if $debug;		
-    }
-
+    
+    push(@groups, $group);
+    push(@groups, "web".$group) if $webgroup;
     push(@{$db_user_group{$user}}, @groups);
 }
 
 # db_groups:
 #
 #    We need to able to determine whether a group is related to
-#    Savannah or not.
+#    Savane or not.
 # 
-my @db_groups = GetGroupList(0, "unix_group_name");
+my %db_groups;
+foreach my $group (GetGroupList(0, "unix_group_name")) {
+    $db_groups{$group} = 1;
+}
 
 print LOG strftime "[$script] %c - database infos grabbed\n", localtime;
 
@@ -430,7 +417,7 @@ foreach my $user (@only_in_db){
 	    
 	    
 	    # Add GPG key
-	    if ($gpg_keys ne "NULL") {
+	    if ($gpg_keys and $gpg_keys ne "NULL" and $gpg_is_enabled) {
 		# For gpg, I have to think about. Would we accept only gpg
 		# signature complete, or fingerprints?
 		$gpg_keys_count = UserAddGPGKey($user, $gpg_keys);
@@ -458,7 +445,7 @@ print LOG strftime "[$script] %c - account creation done\n", localtime;
 
 
 # Remove users marked as D in the database.
-# This is the safest way to remove users quitting savannah.
+# This is the safest way to remove users quitting Savane.
 foreach my $user (@to_be_removed) {
     next if $etc_password_tobeignored{$user};
 
@@ -492,8 +479,15 @@ foreach my $user (@well_known) {
     my @groups_list_etc = 0;
     @groups_list = @{$db_user_group{$user}} if
 	(exists($db_user_group{$user}));
-    @groups_list = (@groups_list, @{$etc_group{$user}}) if
-	(exists($etc_group{$user}));
+    if (exists($etc_group{$user})) {
+	# Add the list only system groups that are not managed by Savane.
+	# We want to avoid removing system groups that have nothing to do
+	# with Savane, but we want to remove Savane groups the user is no
+	# longer member of
+	for (@{$etc_group{$user}}) {
+	    push(@groups_list, $_) unless $db_groups{$_};
+	}
+    }
     @groups_list_etc =  @{$etc_group{$user}} if
 	(exists($etc_group{$user}));
     
@@ -547,7 +541,7 @@ foreach my $user (@well_known) {
     # key by bash login, not by web interface.
     my $ssh_keys_count = 0;
     if ($etc_password{$user}->[8] eq $sys_shell) {
-	print "DBG update: $user ssh key managed by sv\n" if $debug;  
+	print "DBG update: $user ssh key managed by sv\n" if $debug;
 	if ($authorized_keys ne GetUserSSHKeyReal($user)) {
 	    unless ($debug) {
 		$ssh_keys_count = UserAddSSHKey($user, $authorized_keys);
@@ -558,7 +552,7 @@ foreach my $user (@well_known) {
     
     # GPG DEACTIVATED FOR NOW.
     # Will be reactivated with the creation of a mail interface.
-    if (0) {
+    if ($gpg_is_enabled) {
 	# Update GPG key if not accurate
 	my $gpg_keys_count = 0;
 	if ($gpg_keys && $gpg_keys ne "NULL") {
