@@ -2,9 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_update_conf.pl,v 1.25 2004/09/22 08:11:50 yeupou Exp $
+# $Id: sv_update_conf.pl,v 1.29 2005/03/26 08:46:32 yeupou Exp $
 #
-#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
+#                          Sylvain Beucler <beuc--beuc.net>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -213,9 +214,10 @@ if ($recreate) {
 
     
       AskSetting("sys_dbhost", "SQL database hostname", "--", "localhost", $sys_dbhost);
-      AskSetting("sys_dbname", "SQL database name", "--", "savannah", $sys_dbname);
+      AskSetting("sys_dbname", "SQL database name", "--", "savane", $sys_dbname);
       AskSetting("sys_dbuser", "SQL database user", "--", "mysqluser", $sys_dbuser);
       AskSetting("sys_dbpasswd", "SQL database password", "--", "mysqlpasswd", $sys_dbpasswd);
+      AskSetting("sys_dbparams", "Additional database settings", "param=value pairs separated by colons, eg. param1=value1:param2=value2...", "mysql_socket=/non-standard-path-to/mysqld.sock", $sys_dbparams);
 
 
     ## INSTALLATION PATHS ##
@@ -228,8 +230,8 @@ if ($recreate) {
 
     ## GUI ##
 
-      AskSetting("sys_name", "Platform name", "Name shown on public pages for the whole service", "Savannah", $sys_name, 1);
-      AskSetting("sys_unix_group_name", "Server administration project unix name", "Unix group name of the meta-project used for administration. Take care to avoid conflicts with group name existing on your system, take care to select a valid unix group name: no checks will be done for this project unix group name.", "savannah", $sys_unix_group_name);
+      AskSetting("sys_name", "Platform name", "Name shown on public pages for the whole service", "A New Savane Installation", $sys_name, 1);
+      AskSetting("sys_unix_group_name", "Server administration project unix name", "Unix group name of the meta-project used for administration. Take care to avoid conflicts with group name existing on your system, take care to select a valid unix group name: no checks will be done for this project unix group name.", "admin", $sys_unix_group_name);
 
       AskSetting("sys_default_locale", "Default locale", "It must be a valid locale name", "french", $sys_default_locale);
       AskSetting("sys_datefmt", "Date format", "Date formatting. If you want to use the default locale formating, comment out (it's usually a good idea)", "Y-M-d H:i", $sys_datefmt);
@@ -242,7 +244,7 @@ if ($recreate) {
 
       AskSetting("sys_mail_domain", "Mail domain", "--", "gnu.org, \$sys_default_domain", $sys_mail_domain);
       AskSetting("sys_mail_admin", "Admin mail address", "The mail domain we'll be added to this username", "savannah-hackers", $sys_mail_admin);
-      AskSetting("sys_mail_replyto", "Default reply-to address", "--", "noreply", $sys_replyto);
+      AskSetting("sys_mail_replyto", "No reply address used in the trackers", "--", "NO-REPLY.INVALID-ADDRESS", $sys_replyto);
       AskSetting("sys_mail_list", "[BACKEND SPECIFIC] List of emails", "If you do not want such file to be updated by the backend, comment out", "/etc/email-addresses", $sys_mail_list);
       AskSetting("sys_mail_aliases", "[BACKEND SPECIFIC] List of emails aliases", "If you do not want such file to be updated by the backend, comment out", "/etc/aliases", $sys_mail_aliases);
 
@@ -254,7 +256,7 @@ if ($recreate) {
     
     AskSetting("sys_homedir", "[BACKEND SPECIFIC] User home directory", "Usually /home. You can uncomment if you do not plan to provide accounts", "/home", $sys_homedir);
     AskSetting("sys_homedir_subdirs", "[BACKEND SPECIFIC] User home directory subdirs", "Users home is by default /home/user. If you set this to 1, you'll get /home/u/user, and if you set it to 2, you'll get /home/u/us/user. It may be very convenient if you have plenty of users.", "2", $sys_homedir_subdirs);
-    AskSetting("sys_shell", "[BACKEND SPECIFIC] User default shell", "cvssh is a limited shell, choose /bin/bash if you want to provide full access to your users", "/usr/local/bin/cvssh", $sys_shell);
+    AskSetting("sys_shell", "[BACKEND SPECIFIC] User default shell", "cvssh is a limited shell, choose /bin/bash if you want to provide full access to your users", "/usr/local/bin/sv_membersh", $sys_shell);
     
     AskSetting("sys_userx_prefix", "[BACKEND SPECIFIC] Prefix for user* binaries", "If you do not want to use useradd/usermod/userdel that are in the usual PATH but specific ones, you can type here their prefix. Otherwise, comment out", "/usr/local/savannah/bin", $sys_userx_prefix); 
     
@@ -304,7 +306,7 @@ if ($recreate) {
 #
 # Savane Site Configuration:
 #
-# $Id: sv_update_conf.pl,v 1.25 2004/09/22 08:11:50 yeupou Exp $
+# $Id: sv_update_conf.pl,v 1.29 2005/03/26 08:46:32 yeupou Exp $
 #
 # This file has been generated by sv_update_conf
 # If you modify it, run sv_update_conf --update
@@ -359,11 +361,13 @@ use strict;
       $sys_brother_domain
 
       # SQL server:
-      # Ex: "localhost", "savannah", "mysqluser", "mysqlpasswd"
+      # Ex: "localhost", "savannah", "mysqluser", "mysqlpasswd",
+      #     "mysql_socket=/non-standard-path-to/mysqld.sock"
       $sys_dbhost
       $sys_dbname
       $sys_dbuser
       $sys_dbpasswd
+      $sys_dbparams
 
 
     ## INSTALLATION PATHS ##
