@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_mailman.pl,v 1.9 2004/09/22 08:11:50 yeupou Exp $
+# $Id: sv_mailman.pl,v 1.10 2004/12/12 15:36:53 yeupou Exp $
 #
 #  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
 #
@@ -110,7 +110,13 @@ foreach my $line (GetDB("mail_group_list",
     print LOG strftime "[$script] %c - List $name <$admin> newlist.\n", localtime;
     
     # Configure the list.
-    open(TMPCFG, "> /tmp/mmcfg");
+    
+    # Avoid race conditions
+    system("/bin/rm", "-rf", "/tmp/mmcfg");
+    mkdir("/tmp/mmcfg", 0700)
+	or die "Unable to create /tmp/mmcfg safely. Exiting";
+
+    open(TMPCFG, "> /tmp/mmcfg/mmcfg");
     # Always set description
     print TMPCFG "description = '".Escape($description)."'\n";
     # mailman is not useful to fight spam, in fact being forced to use
@@ -129,7 +135,7 @@ foreach my $line (GetDB("mail_group_list",
     close(TMPCFG);
     system("/usr/sbin/config_list",
 	   "--inputfile",
-	   "/tmp/mmcfg",
+	   "/tmp/mmcfg/mmcfg",
 	   $name);
     print LOG strftime "[$script] %c - List $name <$admin> config_list.\n", localtime;
 
@@ -173,7 +179,8 @@ Regards,";
 # Final exit
 print LOG strftime "[$script] %c - work finished\n", localtime;
 print LOG "[$script] ------------------------------------------------------\n";
-unlink($lockfile, "/tmp/mmcfg", "/tmp/mmmail");
+unlink($lockfile, "/tmp/mmcfg/mmcfg");
+system("/bin/rm", "-rf", "/tmp/mmcfg");
 
 # END
 
