@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.50 2004/11/22 09:12:49 yeupou Exp $
+# $Id: index.php,v 1.52 2005/03/22 16:29:08 toddy Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-# 
+#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
@@ -24,7 +24,7 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
-require "../include/pre.php";    
+require "../include/pre.php";
 
 
 #######################
@@ -32,26 +32,30 @@ require "../include/pre.php";
 
 session_require(array('isloggedin'=>1));
 
-if ($update) 
+if ($update)
 {
-  if($user_theme == "Default") 
+  if($user_theme == "Default")
     { $user_theme = ""; }
-  
-  if ($theme_rotate_jump == "1") 
+
+  if ($theme_rotate_jump == "1")
     {
       theme_rotate_jump($theme_rotate_numeric);
-    } 
-  else 
+    }
+  else
     {
       setcookie("SV_THEME", $user_theme, time() + 60*60*24*365, $GLOBALS['sys_home']);
     }
-  
+
   $success = db_query("UPDATE user SET "
 		      . "email_hide=" . ($form_email_hide?"1":"0") . ","
 		      . "theme='" . addslashes($user_theme) . "' WHERE "
 		      . "user_id=" . user_getid());
 
-
+  # Integrated bookmarks
+  if ($form_use_bookmarks == "1")
+    { user_set_preference("use_bookmarks", 1); }
+  else
+    { user_unset_preference("use_bookmarks"); }
 
   ####### Subject line
   # First test content: to avoid people entering white space and being in
@@ -63,7 +67,7 @@ if ($update)
     { user_unset_preference("reverse_comments_order"); }
 
 
-  if ($success) 
+  if ($success)
     {
       fb(_("Succesful update, theme/color changes will be effective the next time a page is loaded"));
     }
@@ -101,10 +105,10 @@ print '</p>';
 unset($i);
 print $HTML->box_nextitem(utils_get_alt_row_color($i));
 print '<a href="sessions.php">';
-printf(gettext("Manage the %d opened session(s)"),session_count(user_getid())); 
+printf(ngettext("Manage the %d opened session", "Manage the %d opened sessions", session_count(user_getid())),session_count(user_getid()));
 print '</a><p class="text">&nbsp;</p>';
 
-# get shared key count from db                                         
+# get shared key count from db
 $expl_keys = explode("###",$row_user['authorized_keys']);
 
 # If the last 'key' is empty, then it is because of a trailing separator;
@@ -116,8 +120,8 @@ if ($expl_keys[$keynum-1] == "")
 $i++;
 print $HTML->box_nextitem(utils_get_alt_row_color($i));
 print '<a href="editsshkeys.php">';
-if ($keynum > 0) 
-{ printf(gettext("Edit the %d SSH Public Key(s) Registered"),($keynum)); }
+if ($keynum > 0)
+{ printf(ngettext("Edit the %d SSH Public Key registered", "Edit the %d SSH Public Keys registered", $keynum), $keynum); }
 else
 { print gettext("Register an SSH Public Key"); }
 
@@ -149,11 +153,11 @@ print '<p class="text">'._("Note: themes use CSS massively and can not be used w
 if (!theme_guidelines_check(SV_THEME))
 {
   print '<p class="text"><font class="warn">'._("The theme you are currently using does not follow the latest Savane CSS guidelines. As result, page layout may be more or less severely broken. It is not advised to use this theme.").' ';
-  # If the non-valid theme is the default one, tell users they should fill 
+  # If the non-valid theme is the default one, tell users they should fill
   # a support request
-  if (SV_THEME == $GLOBALS['sys_themedefault']) 
+  if (SV_THEME == $GLOBALS['sys_themedefault'])
     {
-      print utils_link($GLOBALS['sys_home'].'support/?group='.$GLOBALS['sys_unix_group_name'], 
+      print utils_link($GLOBALS['sys_home'].'support/?group='.$GLOBALS['sys_unix_group_name'],
 		       sprintf(_("%s administrators should be asked to take care of Savane CSS Guidelines, since it is the default theme"), $GLOBALS['sys_name']), "warn");
     }
   print '</font></p>';
@@ -168,6 +172,13 @@ print '<p class="text">'._("Here is defined when the trackers should send email
 $i++;
 print $HTML->box_nextitem(utils_get_alt_row_color($i));
 
+print '<input type="checkbox" name="form_use_bookmarks" value="1" '.(user_get_preference("use_bookmarks") ? 'checked="checked"':'').' /> '._("Use integrated bookmarks");
+
+print '<p class="text">'._("By default, integrated bookmarks are deactivated to avoid redundancy with the bookmark feature provided by most modern web browsers. However, you may prefer integrated bookmarks if you frequently use different workstations without web browsers bookmarks synchronization.").'</p>';
+
+$i++;
+print $HTML->box_nextitem(utils_get_alt_row_color($i));
+
 print '<input type="checkbox" name="form_email_hide" value="1" '.($row_user['email_hide'] ? 'checked="checked"':'').' /> '._("Hide email address from your account information");
 
 print '<p class="text">'._("So the only way to get in touch with you would be using the form available to logged-in users. It is generally a bad idea to choose this option, especially if I am a project administrator.").'</p>';
