@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: lostpw-confirm.php,v 1.22 2004/11/22 08:25:48 yeupou Exp $
+# $Id: lostpw-confirm.php,v 1.23 2005/03/21 20:38:12 toddy Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -23,7 +23,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-require "../include/pre.php";    
+require "../include/pre.php";
 
 
 # CERN_SPECIFIC: here we also have a speech about AFS which must not be
@@ -44,11 +44,11 @@ if ($GLOBALS['sys_use_pamauth'] == "yes") {
 $confirm_hash = md5($session_hash . strval(time()) . strval(rand()));
 
 $res_user = db_query("SELECT * FROM user WHERE user_name='$form_loginname' AND status='A'");
-if (db_numrows($res_user) < 1) 
+if (db_numrows($res_user) < 1)
 {
-  exit_error(_("Invalid User"), _("This account account does exists or have not been activated"));
+  exit_error(_("Invalid User"), _("This account does exist or has not been activated"));
 }
-       
+
 $row_user = db_fetch_array($res_user);
 
 db_query("UPDATE user SET confirm_hash='$confirm_hash' WHERE user_id=$row_user[user_id]");
@@ -65,7 +65,7 @@ $message .= _("In any case make sure that you do not disclose this url to\n somb
 $message .= sprintf(_("-- the %s team."),$GLOBALS['sys_name'])."\n";
 
 # We should not add i18n to admin messages
-$message_for_admin = 
+$message_for_admin =
 "Someone attempted to change a password via email verification\n"
 . "on ".$GLOBALS['sys_default_domain']."\n\n"
 . "Someone is maybe trying to steal a user account.\n\n"
@@ -76,7 +76,7 @@ $message_for_admin =
 . "RFC 822 (updated by RFC 1123) date:\n"
 . gmdate('D, d M Y H:i:s \G\M\T')
      . "\n";
-	
+
 sendmail_mail($GLOBALS['sys_mail_replyto']."@".$GLOBALS['sys_mail_domain'],
 	      $row_user['email'],
 	      $GLOBALS['sys_default_domain']." Verification",
