@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: groupedit.php,v 1.57 2004/11/22 08:25:48 yeupou Exp $
+# $Id: groupedit.php,v 1.58 2005/03/20 11:47:20 yeupou Exp $
 #
 #
 # Copyright 1999-2000 (c) The SourceForge Crew
@@ -56,7 +56,7 @@ if ($update)
     }
 
   db_query("UPDATE groups SET is_public=$form_public,status='$form_status',"
-	   . "license='$form_license',type='$group_type',unix_group_name='$form_name',dir_cvs='$form_dir_cvs',dir_homepage='$form_dir_homepage',dir_download='$form_dir_download'  WHERE group_id=$group_id");
+	   . "license='$form_license',type='$group_type',unix_group_name='$form_name',dir_arch='$form_dir_arch',dir_svn='$form_dir_svn',dir_cvs='$form_dir_cvs',dir_homepage='$form_dir_homepage',dir_download='$form_dir_download'  WHERE group_id=$group_id");
 
   fb(_("Updating Project Info"));
 }
@@ -165,16 +165,30 @@ print '
 
 $HTML->box1_bottom();
 
+print '<p><a href="triggercreation.php?group_id='.$group_id.'">'._("Send New Project Instruction Email and Trigger Project Creation (should be done only once)").'</a>';
+
+print '</p>';
+
 $HTML->box1_top(_("Specific Backend Settings"));
 print '[BACKEND SPECIFIC] If this group must have specific directories for homepage, sourcecode, download, which are not the default of the group type it belongs to, you can fill the following fields. You may need to also edit the urls in  \'This Project Active Features\'. You should avoid as possible using these fields and consider creating new group types. Exceptions are a pain to handle in the long run.';
 $i=0;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
-print '<p><font class="preinput">'._("Sourcecode (CVS) directory:").'</font><br /> ';
+print '<p><font class="preinput">'._("Primary SCM (CVS) directory:").'</font><br /> ';
 print '<input type="text" name="form_dir_cvs" value="'.$row_grp['dir_cvs'].'" size="50">';
 $i++;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
+print '<p><font class="preinput">'._("Secondary SCM (Arch) directory:").'</font><br /> ';
+print '<input type="text" name="form_dir_arch" value="'.$row_grp['dir_arch'].'" size="50">';
+$i++;
+print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
+
+print '<p><font class="preinput">'._("Tertiary SCM (Subversion) directory:").'</font><br /> ';
+print '<input type="text" name="form_dir_svn" value="'.$row_grp['dir_svn'].'" size="50">';
+$i++;
+print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
+
 print '<p><font class="preinput">'._("Homepage directory:").'</font><br /> ';
 print '<input type="text" name="form_dir_homepage" value="'.$row_grp['dir_homepage'].'" size="50">';
 $i++;
@@ -188,7 +202,7 @@ print '
 $HTML->box1_bottom();
 
 
-print '<p><a href="triggercreation.php?group_id='.$group_id.'">'._("Send New Project Instruction Email and Trigger Project Creation").'</a>';
+print '<p><a href="triggercreation.php?group_id='.$group_id.'">'._("Send New Project Instruction Email and Trigger Project Creation (should be done only once)").'</a>';
 
 
 # we get site-specific content
