@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: usergroup.php,v 1.11 2004/09/22 08:11:50 yeupou Exp $
+// $Id: usergroup.php,v 1.12 2004/11/22 08:25:48 yeupou Exp $
 //
 //
 // 
@@ -70,31 +70,13 @@ if ($action=='remove_user_from_group') {
 		Update the user
 	*/
 
-	$result=db_query("UPDATE user SET shell='$form_shell', email='$email' WHERE user_id=$user_id");
+	$result=db_query("UPDATE user SET email='$email' WHERE user_id=$user_id");
 	if (!$result || db_affected_rows($result) < 1) {
 		' Error Updating User ';
 		echo db_error();
 	} else {
 		' Successfully updated user ';
 	}
-	// status changing
-	if ($form_unixstatus != 'N') {
-		$res_uid = db_query("SELECT unix_uid FROM user WHERE user_id=$user_id");
-		$row_uid = db_fetch_array($res_uid);
-		if ($row_uid[unix_uid] == 0) {
-			// need to create uid
-			db_query("UPDATE user SET unix_uid=" . account_nextuid() . " WHERE user_id=$user_id");
-		} 
-		// now do update
-		$result=db_query("UPDATE user SET unix_status='$form_unixstatus' WHERE user_id=$user_id");	
-		if (!$result || db_affected_rows($result) < 1) {
-			' Error Updating Unix ';
-			echo db_error();
-		} else {
-			'Successfully updated unix ';
-		}
-
-	}
 
 } else if ($action=='add_user_to_group') {
 	/*
@@ -117,31 +99,11 @@ $row_user = db_fetch_array($res_user);
 <p>
 Savannah User Group Edit for user: <b><?php print $user_id . ": " . user_getname($user_id); ?></b>
 <p>
-Unix Account Info:
+Account Info:
 <FORM method="post" action="<?php echo $PHP_SELF; ?>">
 <INPUT type="hidden" name="action" value="update_user">
 <INPUT type="hidden" name="user_id" value="<?php print $user_id; ?>">
 
-<P>
-Shell:
-<SELECT name="form_shell">
-<?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: usergroup.php,v 1.11 2004/09/22 08:11:50 yeupou Exp $
-// account_shellselects($row_user[shell]); ?>
-</SELECT>
-
-<P>
-Unix Account Status:
-<SELECT name="form_unixstatus">
-<OPTION <?php echo ($row_user[unix_status] == 'N') ? 'selected ' : ''; ?>value="N">No Unix Account
-<OPTION <?php echo ($row_user[unix_status] == 'A') ? 'selected ' : ''; ?>value="A">Active
-<OPTION <?php echo ($row_user[unix_status] == 'S') ? 'selected ' : ''; ?>value="S">Suspended
-<OPTION <?php echo ($row_user[unix_status] == 'D') ? 'selected ' : ''; ?>value="D">Deleted
-</SELECT>
-
 <P>
 <INPUT TYPE="TEXT" NAME="email" VALUE="<?php echo $row_user[email]; ?>" SIZE="25" MAXLENGTH="55">
 
@@ -160,7 +122,7 @@ Unix Account Status:
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: usergroup.php,v 1.11 2004/09/22 08:11:50 yeupou Exp $
+// $Id: usergroup.php,v 1.12 2004/11/22 08:25:48 yeupou Exp $
 //
 /*
 	Iterate and show groups this user is in
@@ -214,7 +176,7 @@ Add User to Group (group_id):
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: usergroup.php,v 1.11 2004/09/22 08:11:50 yeupou Exp $
+// $Id: usergroup.php,v 1.12 2004/11/22 08:25:48 yeupou Exp $
 //
 html_feedback_bottom($feedback);
 $HTML->footer(array());
