@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: account.php,v 1.20 2004/06/26 10:44:32 yeupou Exp $
+# $Id: account.php,v 1.22 2004/11/22 08:25:48 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -32,7 +32,7 @@ function account_pwvalid ($pw)
   if (strlen($pw) < $MIN_PASSWD_LENGTH)
     {
       $GLOBALS['register_error'] = sprintf(_("Password must be at least %s characters."),$MIN_PASSWD_LENGTH);
-      $GLOBALS['ffeedback'] = sprintf(_("Password must be at least %s characters."),$MIN_PASSWD_LENGTH);
+      fb(sprintf(_("Password must be at least %s characters."),$MIN_PASSWD_LENGTH),1);
       return 0;
     }
   return 1;
@@ -57,7 +57,7 @@ function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1)
   # no spaces
   if (strrpos($name,' ') > 0)
     {
-      $GLOBALS['register_error'] = _("There cannot be any spaces in the login name.");	
+      fb(_("There cannot be any spaces in the login name."),1);	
       return 0;
     }
 
@@ -67,20 +67,20 @@ function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1)
 
   if (strlen($name) < $MIN_ACCNAME_LENGTH)
     {
-      $GLOBALS['register_error'] = sprintf(_("Account name is too short. It must be at least %s characters."), $MIN_ACCNAME_LENGTH);
+      fb(sprintf(_("Account name is too short. It must be at least %s characters."), $MIN_ACCNAME_LENGTH),1);
       return 0;
     }
 
   if (strlen($name) > $MAX_ACCNAME_LENGTH)
     {
-      $GLOBALS['register_error'] = sprintf(_("Account name is too long. It must be at most %s characters."), $MAX_ACCNAME_LENGTH);
+      fb(sprintf(_("Account name is too long. It must be at most %s characters."), $MAX_ACCNAME_LENGTH),1);
       return 0;
     }
 
   # must start with an alphanumeric non numeric
   if (strspn($name,"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ") == 0)
     {
-      $GLOBALS['register_error'] = _("Account name must begin with an alphabetical character.");
+      fb(_("Account name must begin with an alphabetical character."),1);
       return 0;
     }
 
@@ -90,20 +90,20 @@ function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1)
       != strlen($name))
     {
       if ($allow_underscore) 
-	{ $GLOBALS['register_error'] = _("Account name must only contain alphanumerics and underscores."); }
+	{ fb(_("Account name must only contain alphanumerics and underscores."),1); }
       elseif ($allow_dashes) 
-	{ $GLOBALS['register_error'] = _("Account name must only contain alphanumerics and dashes."); }
-      else { $GLOBALS['register_error'] = _("Account name must only contain alphanumerics."); }
+	{ fb(_("Account name must only contain alphanumerics and dashes."),1); }
+      else { fb(_("Account name must only contain alphanumerics."),1); }
 
       return 0;
     }
     
   # illegal names
   if (eregi("^((root)|(bin)|(daemon)|(adm)|(lp)|(sync)|(shutdown)|(halt)|(mail)|(news)"
-	    . "|(uucp)|(operator)|(invalid)|(games)|(mysql)|(httpd)|(nobody)|(dummy)|(opensource)"
+	    . "|(uucp)|(apache)|(operator)|(invalid)|(games)|(mysql)|(httpd)|(nobody)|(dummy)|(opensource)"
 	    . "|(web)|(www)|(cvs)|(anoncvs)|(anonymous)|(shell)|(ftp)|(irc)|(debian)|(ns)|(download))$",$name))
     {
-      $GLOBALS['register_error'] = _("That account name is reserved.");
+      fb(_("That account name is reserved."),1);
       return 0;
     }
 		
@@ -182,7 +182,7 @@ function account_groupnamevalid ($name)
       dbg("apply standard regexp");
       if (preg_match($forbid_group_regexp,$name))
 	{
-	  $GLOBALS['register_error'] = _("This group name is not allowed.");
+	  fb(_("This group name is not allowed."),1);
 	  return 0;
 	}
     }
@@ -194,14 +194,14 @@ function account_groupnamevalid ($name)
       dbg("apply specific regexp");
       if (preg_match($GLOBALS['specific_forbid_group_regexp'],$name))
 	{
-	  $GLOBALS['register_error'] = _("This group name is not allowed.");
+	  fb(_("This group name is not allowed."),1);
 	  return 0;
 	}
     }
   
   if (eregi("_",$name))
     {
-      $GLOBALS['register_error'] = _("Group name cannot contain underscore for DNS reasons.");
+      fb(_("Group name cannot contain underscore for DNS reasons."),1);
       return 0;
     }
 
