@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: html.php,v 1.53 2004/11/22 08:25:48 yeupou Exp $
+# $Id: html.php,v 1.57 2005/03/21 14:54:39 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -88,10 +88,19 @@ function html_anchor ($content, $name)
 function html_feedback_top()
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_feedback_top() ';
-  if ($GLOBALS[feedback])
-    {  print '<h3 class="feedback">'.htmlentities($GLOBALS[feedback]).'</h3>'; }
-  if ($GLOBALS[ffeedback])
-    {  print '<h3 class="feedbackerror">'.htmlentities($GLOBALS[ffeedback]).'</h3>'; }
+
+  # Only success
+  if ($GLOBALS[feedback] && !$GLOBALS[ffeedback])
+    {  print '<h3 class="feedback"><span class="feedbacktitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/ok.png" class="feedbackimage" alt="'._("Success").'" /> '._("Success:").'</span> '.htmlentities($GLOBALS[feedback]).'</h3>'; }
+
+  # Only errors
+  if ($GLOBALS[ffeedback] && !$GLOBALS[feedback])
+    {  print '<h3 class="feedbackerror"><span class="feedbackerrortitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" class="feedbackimage" alt="'._("Error").'" /> '._("Error:").'</span>'.htmlentities($GLOBALS[ffeedback]).'</h3>'; }
+
+  # Errors and success
+  if ($GLOBALS[ffeedback] && $GLOBALS[feedback])
+    {  print '<h3 class="feedbackerrorandsuccess"><span class="feedbackerrorandsuccesstitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" class="feedbackimage" alt="'._("Some Errors").'" /> '._("Some Errors:").'</span>'.htmlentities($GLOBALS[feedback]).' '.htmlentities($GLOBALS[ffeedback]).'</h3>'; }
+  
   if ($GLOBALS[sys_debug_on] && $GLOBALS[debug])
     {  print '<h3 class="debug">DEBUG information: '.$GLOBALS[debug].'</h3>'; }
   # yeupou@gnu.org 2003-11-03:
@@ -328,14 +337,14 @@ function html_build_select_box_from_arrays ($vals,
   if ($show_any)
     {
       $selected = ( $checked_val == 0 ? 'selected="selected"':'');
-      $return .= "\n<OPTION VALUE=\"0\" $selected>$text_any </OPTION>";
+      $return .= "\n<option value=\"0\" $selected>$text_any </option>";
     }
 
   #we don't always want the default 100 row shown
   if ($show_100)
     {
       $selected = ( $checked_val == 100 ? 'selected="selected"':'');
-      $return .= "\n<OPTION VALUE=\"100\" $selected>$text_100 </OPTION>";
+      $return .= "\n<option value=\"100\" $selected>$text_100 </option>";
     }
 
 
@@ -419,7 +428,7 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
   if ($show_any)
     {
       $return .= '
-		<OPTION VALUE="0"';
+		<option value="0"';
       for ($j=0; $j<$checked_count; $j++)
 	{
 	  if ($checked_array[$j] == '0')
@@ -427,7 +436,7 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 	      $return .= ' selected="selected"';
 	    }
 	}
-      $return .= '>'.$text_any.'</OPTION>';
+      $return .= '>'.$text_any.'</option>';
     }
 
   /*
@@ -436,7 +445,7 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
   if ($show_100)
     {
       $return .= '
-		<OPTION VALUE="100"';
+		<option value="100"';
       for ($j=0; $j<$checked_count; $j++)
 	{
 	  if ($checked_array[$j] == '100')
@@ -444,7 +453,7 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 	      $return .= ' selected="selected"';
 	    }
 	}
-      $return .= '>'.$text_100.'</OPTION>';
+      $return .= '>'.$text_100.'</option>';
     }
 
   $rows=db_numrows($result);
@@ -454,7 +463,7 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
       if (db_result($result,$i,0) != '100')
 	{
 	  $return .= '
-				<OPTION VALUE="'.db_result($result,$i,0).'"';
+				<option value="'.db_result($result,$i,0).'"';
 	  /*
 				Determine if it's checked
 	  */
@@ -467,7 +476,7 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 		}
 	    }
 	  $return .= '>'. ($show_value?$val.'-':'').
-	     substr(db_result($result,$i,1),0,35). '</OPTION>';
+	     substr(db_result($result,$i,1),0,35). '</option>';
 	}
     }
   $return .= '
@@ -608,17 +617,20 @@ function html_select_restriction_box ($artifact, $row, $level="group", $notd=0)
 function html_select_typedir_box ($input_name, $current_value)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_select_typedir_box ';
-  print '<br />
+  print '<br />&nbsp;&nbsp;
       <select name="'.$input_name.'">
-        <option value="basiccvs"'.(($current_value == "basiccvs")?" selected=\"selected\"":"").'>'._("Basic Cvs Directory").'</option>
         <option value="basicdirectory"'.(($current_value == "basicdirectory")?" selected":"").'>'._("Basic Directory").'</option>
+        <option value="basiccvs"'.(($current_value == "basiccvs")?" selected=\"selected\"":"").'>'._("Basic Cvs Directory").'</option>
+        <option value="basicsvn"'.(($current_value == "basicsvn")?" selected=\"selected\"":"").'>'._("Basic Subversion Directory").'</option>
         <option value="cvsattic"'.(($current_value == "cvsattic")?" selected=\"selected\"":"").'>'._("Cvs Attic").'</option>
+        <option value="savannah-gnu"'.(($current_value == "savannah-gnu")?" selected=\"selected\"":"").'>'._("Savannah GNU").'</option>
+        <option value="savannah-nongnu"'.(($current_value == "savannah-nongnu")?" selected=\"selected\"":"").'>'._("Savannah non-GNU").'</option>
       </select> [BACKEND SPECIFIC]
 ';
 
   # put some information
-  print '<br /><font class="italic">Basic directory will make the backend using DownloadMakeArea(), defined in Savannah::Download; <br /> CVS directory will make the backend using CvsMakeArea(), defined in Savannah::Cvs;<br />
-(If you need to build directories with another method, the solution is to write a new sub in the appropriate perl module, please send a mail to savane-dev@gna.org to get information about that)</font><br />';
+  print '<br /><font class="smaller">Basic directory will make the backend using DownloadMakeArea(), defined in Savannah::Download; <br /> CVS directory will make the backend using CvsMakeArea(), defined in Savannah::Cvs;<br />
+(If you need to build directories with another method, the solution is to write a new sub in the appropriate perl module, please send a mail to savane-dev@gna.org to get information about that)</font><br /><br />';
 
 }
 
@@ -673,24 +685,24 @@ function html_build_priority_select_box ($name='priority', $checked_val='5')
   */
     ?>
      <SELECT NAME="<?php print $name; ?>">
-	<OPTION VALUE="1"<?php if ($checked_val=="1")
-	  {print " selected=\"selected\"";} ?>>1 - Lowest</OPTION>
-				    <OPTION VALUE="2"<?php if ($checked_val=="2")
-				      {print " selected=\"selected\"";} ?>>2</OPTION>
-								<OPTION VALUE="3"<?php if ($checked_val=="3")
-								  {print " selected=\"selected\"";} ?>>3</OPTION>
-											    <OPTION VALUE="4"<?php if ($checked_val=="4")
-											      {print " selected=\"selected\"";} ?>>4</OPTION>
-															<OPTION VALUE="5"<?php if ($checked_val=="5")
-															  {print " selected=\"selected\"";} ?>>5 - Medium</OPTION>
-																		    <OPTION VALUE="6"<?php if ($checked_val=="6")
-																		      {print " selected=\"selected\"";} ?>>6</OPTION>
-																						<OPTION VALUE="7"<?php if ($checked_val=="7")
-																						  {print " selected=\"selected\"";} ?>>7</OPTION>
-																									    <OPTION VALUE="8"<?php if ($checked_val=="8")
-																									      {print " selected=\"selected\"";} ?>>8</OPTION>
-																													<OPTION VALUE="9"<?php if ($checked_val=="9")
-																													  {print " selected=\"selected\"";} ?>>9 - Highest</OPTION>
+	<option value="1"<?php if ($checked_val=="1")
+	  {print " selected=\"selected\"";} ?>>1 - Lowest</option>
+				    <option value="2"<?php if ($checked_val=="2")
+				      {print " selected=\"selected\"";} ?>>2</option>
+								<option value="3"<?php if ($checked_val=="3")
+								  {print " selected=\"selected\"";} ?>>3</option>
+											    <option value="4"<?php if ($checked_val=="4")
+											      {print " selected=\"selected\"";} ?>>4</option>
+															<option value="5"<?php if ($checked_val=="5")
+															  {print " selected=\"selected\"";} ?>>5 - Medium</option>
+																		    <option value="6"<?php if ($checked_val=="6")
+																		      {print " selected=\"selected\"";} ?>>6</option>
+																						<option value="7"<?php if ($checked_val=="7")
+																						  {print " selected=\"selected\"";} ?>>7</option>
+																									    <option value="8"<?php if ($checked_val=="8")
+																									      {print " selected=\"selected\"";} ?>>8</option>
+																													<option value="9"<?php if ($checked_val=="9")
+																													  {print " selected=\"selected\"";} ?>>9 - Highest</option>
 																																    </SELECT>
 																																    <?php
 
