@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: forum.php,v 1.6 2004/09/23 12:16:34 yeupou Exp $
+# $Id: forum.php,v 1.7 2004/11/22 08:25:50 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) ...
+#  Copyright 2004      (c) Mathieu Roy <yeupou--gnu.org>.
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -134,8 +134,8 @@ function forum_header($params)
             if (!$result || db_numrows($result) < 1)
                 {	
                     $is_news=0;
-                    #echo '<font class="error">'._("Error").' - '._("This news item was not found").'</font>';
-                    #echo "forum_name=$forum_name<br />";
+                    #print '<font class="error">'._("Error").' - '._("This news item was not found").'</font>';
+                    #print "forum_name=$forum_name<br />";
                     site_project_header($params);
                     #site_project_header(array('group'=>$group_id,'toptab'=>'forum'));	
                 } 
@@ -152,22 +152,29 @@ function forum_header($params)
 		    $group_id = db_result($result,0,'group_id');
                     $params['toptab']='news';
                     site_project_header($params);  
+
+		    print '
+<div class="indexright">
+';
+                    print $HTML->box_top(_("Latest News"));
+                    print news_show_latest(db_result($result,0,'group_id'),5, "false");
+                    print $HTML->box_bottom();
+		    print '</div>
+<div class="indexcenter">
+';
+
 			
-                    echo '<table><tr><td valign="top">';
+                    print '<h3>'._("Item posted by").' '.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by')));
+                    print ' '._("on").' '. format_date($sys_datefmt,db_result($result,0,'date')).'</h3>';
+                    print '<p>';
+                    print  utils_make_links(nl2br( db_result($result,0,'details')), $group_id);
 			
-                    echo '<h3>'._("Item posted by").' '.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by')));
-                    echo ' '._("on").' '. format_date($sys_datefmt,db_result($result,0,'date')).'</h3>';
-                    echo '<p>';
-                    echo  utils_make_links(nl2br( db_result($result,0,'details')), $group_id);
-			
-                    echo '<P>';
+                    print '<p>';
 # could this fix the bug #409 ?
                     $forum_name = db_result($result,0,'summary');
-                    echo '</td><td valign="top" width="35%">';
-                    echo $HTML->box1_top(_("Latest News"),0);
-                    echo news_show_latest(db_result($result,0,'group_id'),5, "false");
-                    echo $HTML->box1_bottom();
-                    echo '</td></tr></table>';
+		    print '</div>
+';
+
                 }
         }
 	
@@ -177,13 +184,13 @@ function forum_header($params)
 	*/
 	if ($forum_id && $forum_name && $is_news)
         {
-            echo '<H3>'._("Comments").'</H3>';
+            print '<h3 class="clearr">'._("Comments").'</h3>';
         }
-	echo '<P><B>';
+	print '<P><B>';
 	
 	if ($forum_id && user_isloggedin())
         {
-            echo '<a href="'.$GLOBALS['sys_home'].'forum/monitor.php?forum_id='.$forum_id.'">' .
+            print '<a href="'.$GLOBALS['sys_home'].'forum/monitor.php?forum_id='.$forum_id.'">' .
                 #'<img src="'.$GLOBALS['sys_home'].'images/ic/check.png" alt="monitor">
                 _("Monitor Forum (toggle)").'</a> | '.
                 '<a href="'.$GLOBALS['sys_home'].'forum/save.php?forum_id='.$forum_id.'">'.
@@ -198,10 +205,10 @@ function forum_header($params)
 	/*  This functionality is depreated 
     if (user_is_super_user()) alternatively: user_ismember($group_id, "F2")
       {
-        echo ' | <A HREF="'.$GLOBALS['sys_home'].'forum/admin/?group_id='.$group_id.'">Admin</A></B>';
+        print ' | <A HREF="'.$GLOBALS['sys_home'].'forum/admin/?group_id='.$group_id.'">Admin</A></B>';
       }
 	*/      
-	echo '<P>';
+	print '<P>';
 }
 
 # Backward compatibility
@@ -434,8 +441,8 @@ function get_next_thread_id()
 
 	if (!$result)
         {
-            echo '<H1>Error!</H1>';
-            echo db_error();
+            print '<H1>Error!</H1>';
+            print db_error();
             exit;
         } 
 	else
@@ -504,7 +511,7 @@ function post_message($thread_id, $is_followup_to, $subject, $body, $group_forum
                 } 
             else
                 {
-                    echo db_error();
+                    print db_error();
                 }
 		
             if (!$thread_id)
@@ -549,8 +556,8 @@ function post_message($thread_id, $is_followup_to, $subject, $body, $group_forum
 		
             if (!$result)
                 {
-                    echo "INSERT FAILED";
-                    echo db_error();
+                    print "INSERT FAILED";
+                    print db_error();
                     ' '._("Posting Failed").' ';
                 } 
             else
@@ -565,7 +572,7 @@ function post_message($thread_id, $is_followup_to, $subject, $body, $group_forum
 	else
         {
 		
-            echo '<h3>'._("You could post if you were logged in").'.</h3>';
+            print '<h3>'._("You could post if you were logged in").'.</h3>';
 		
         }
 	
@@ -586,33 +593,33 @@ function show_post_form($forum_id, $thread_id=0, $is_followup_to=0, $subject="")
                         }
                 }
 		
-            echo '<center>';
-            echo '<form action="'.$GLOBALS['sys_home'].'forum/forum.php" method="POST">';
-            echo '<input type="hidden" name="post_message" value="y">';
-            echo '<input type="HIDDEN" name="forum_id" value="'.$forum_id.'">';
-            echo '<input type="HIDDEN" name="thread_id" value="'.$thread_id.'">';
-            echo '<input type="HIDDEN" name="msg_id" value="'.$is_followup_to.'">';
-            echo '<input type="HIDDEN" name="is_followup_to" value="'.$is_followup_to.'">';
-            echo '<table><tr><td><b>'._("Subject").':</td><td>';
-            echo '<input type="TEXT" name="subject" value="'.$subject.'" size="60" maxlength="45">';
-            echo '</td></tr>';
-            echo '<tr><td><b>'._("Message").':</td><td>';
-            echo '<textarea name="body" value="" rows="25" cols="60" wrap="SOFT"></textarea>';
-			echo '</td></tr>';
-			echo '<tr><td colspan="2" align="MIDDLE">';
-			echo '<font class="warn">HTML tags will display in your post as text</font>';
-			echo '<br />';
-			echo '<input type="SUBMIT" name="SUBMIT" value="'._("Post Comment").'">';
-			echo '</td></tr></table>';
-			echo '</form>';
-			echo '</center>';
+            print '<center>';
+            print '<form action="'.$GLOBALS['sys_home'].'forum/forum.php" method="POST">';
+            print '<input type="hidden" name="post_message" value="y">';
+            print '<input type="HIDDEN" name="forum_id" value="'.$forum_id.'">';
+            print '<input type="HIDDEN" name="thread_id" value="'.$thread_id.'">';
+            print '<input type="HIDDEN" name="msg_id" value="'.$is_followup_to.'">';
+            print '<input type="HIDDEN" name="is_followup_to" value="'.$is_followup_to.'">';
+            print '<table><tr><td><b>'._("Subject").':</td><td>';
+            print '<input type="TEXT" name="subject" value="'.$subject.'" size="60" maxlength="45">';
+            print '</td></tr>';
+            print '<tr><td><b>'._("Message").':</td><td>';
+            print '<textarea name="body" value="" rows="25" cols="60" wrap="SOFT"></textarea>';
+			print '</td></tr>';
+			print '<tr><td colspan="2" align="MIDDLE">';
+			print '<font class="warn">HTML tags will display in your post as text</font>';
+			print '<br />';
+			print '<input type="SUBMIT" name="SUBMIT" value="'._("Post Comment").'">';
+			print '</td></tr></table>';
+			print '</form>';
+			print '</center>';
 
 		} 
 	else 
         {
-            echo "<center>";
-            echo "\n\n<font class=\"error\">"._("You could post if you were logged in").'</font>';
-            echo "</center>";
+            print "<center>";
+            print "\n\n<font class=\"error\">"._("You could post if you were logged in").'</font>';
+            print "</center>";
 		
         }
 	
@@ -694,7 +701,7 @@ function handle_monitoring($forum_id,$msg_id)
 
 # Custom extensions to the header:
 /*
-                            echo "Just executed <br />".
+                            print "Just executed <br />".
                             "sendmail_mail (from: $from, <br />to: $to, <br />subject: $subject, <br />message: $message, <br />".
                                            "savannah_project: $savannah_project, <br />savannah_artifact: $savannah_artifact,<br />".
                                            "savannah_artifact_id: $savannah_artifact_id, <br />reply_to: $reply_to,<br />".
@@ -742,13 +749,13 @@ function handle_monitoring($forum_id,$msg_id)
             else
                 {
                     ' email not sent - people monitoring ';
-                    echo db_error();
+                    print db_error();
                 }
         } 
 	else
         {
             ' email not sent - no one monitoring ';
-            echo db_error();
+            print db_error();
         }
 }
 
