@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.17 2004/11/22 08:25:50 yeupou Exp $
+# $Id: general.php,v 1.20 2005/03/21 22:16:35 toddy Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) ...
+#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -89,7 +89,11 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
 	    {
 	      # Get the story
 	      $story = rtrim(db_result($result,$i,'details'));
-	      if (strlen($story) > 250)
+
+	      # if the news item is large (>500), only show the first
+	      # 250 characters of the story
+	      # Fixes bug #1934 -- toddy 2005-02-11
+	      if (strlen($story) > 500)
 	        {
 	          # create an abstract with a [read more] link
 		  $summ_txt = substr($story, 0, 250);
@@ -110,25 +114,16 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
 	      $proj_name='';
 	      $summ_txt='';
 	    }
-      # this is still not proper i18n, but at least it displays correctly
-      # "0 entries" instead of "0 entry" -- toddy 2004-03-04
-      if ($trow_count == 1)
-	{
-	  $reply = _("reply");
-	}
-      else
-	{
-	  $reply = _("replies");
-	}
+      $reply = sprintf(ngettext("%s reply", "%s replies", $trow_count), $trow_count);
 
       $return .=
         news_new_subbox($i+1)
 	.'<a href="'.$GLOBALS['sys_home'].'forum/forum.php?forum_id='.db_result($result,$i,'forum_id').'"><b>'.db_result($result,$i,'summary').'</b></a>';
-      if ($show_summaries != "false") 
+      if ($show_summaries != "false")
 	{ $return .= '<br />&nbsp;&nbsp;&nbsp;&nbsp;'; }
       $return .= ' <font class="smaller"><i>'._("posted by").' <a href="'
 	.$GLOBALS['sys_home'].'users/'. db_result($result,$i,'user_name') .'">'. db_result($result,$i,'user_name')
-	.'</a>, '. format_date($sys_datefmt,db_result($result,$i,'date')) .' - '.$trow_count.' '
+	.'</a>, '. format_date($sys_datefmt,db_result($result,$i,'date')) .' - '
 	.$reply.'</i></font>'.$summ_txt;
 
 	}
@@ -144,12 +139,12 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
 	  # You can only submit news from a project now.
 	  # You used to be able to submit general news.
 	  $return .= news_new_subbox($i)
-	     .'<a href="'.$GLOBALS['sys_home'].'news/submit.php?group_id='
+	     .'<br /> <a href="'.$GLOBALS['sys_home'].'news/submit.php?group_id='
 	     .$group_id.'"><font size="-1">['._("Submit News").']</font></a>';
 	}
 
       $return .= news_new_subbox($i)
-	 .'<a href="'.$GLOBALS['sys_home'].'news/?group_id='.$group_id.'"><font size="-1">['
+	 .'<br /> <a href="'.$GLOBALS['sys_home'].'news/?group_id='.$group_id.'"><font size="-1">['
 	 .$news_total.' '._("News in Archives").']</font></a>';
     }
 
