@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: pre.php,v 1.79 2004/11/22 08:25:48 yeupou Exp $
+# $Id: pre.php,v 1.80 2005/03/20 16:40:46 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -205,16 +205,8 @@ require $GLOBALS['sys_urlroot'].'/include/menu.php';
 **************************************************************/
 
 # Connect to db
-
 db_connect();
 
-if (!$conn) 
-{
-  print "Could Not Connect to Database".db_error();
-  exit;
-}
-
-
 # sys_unix_group_name is maybe defined
 # in this case, we want sys_group_id
 if (isset($GLOBALS['sys_unix_group_name'])) 
