@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: project_home.php,v 1.110 2004/11/22 08:25:48 yeupou Exp $
+# $Id: project_home.php,v 1.113 2005/03/20 11:47:20 yeupou Exp $
 #
 # Copyright 1999-2000 (c) The SourceForge Crew
 # Copyright 2000-2003 (c) Free Software Foundation
@@ -26,6 +26,7 @@
 
 require_directory("people");
 require_directory("news");
+require_directory("stats");
 require $GLOBALS['sys_urlroot']."/include/vars.php";
 
 # if we are at wrong url, redirect
@@ -186,7 +187,7 @@ if ($GLOBALS[sys_group_id] == $group_id)
 
       print $HTML->box_nextitem(utils_get_alt_row_color($i+1));
 
-      print utils_link($GLOBALS['sys_home'].'admin/approve-pending.php',
+      print utils_link($GLOBALS['sys_home'].'task/?group='.$GLOBALS['sys_unix_group_name'].'&amp;category_id=1&amp;status_id=1&amp;set=custom',
 		       html_image("admin.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Server Admin"))).'&nbsp;'._("Pending Projects List"));
       $registration_count = number_format(stats_getprojects_pending());
       if ($registration_count > 1) 
@@ -329,7 +330,7 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
 
 
   # Fora
-  # It must be reactivated on Savannah.
+  # Could be reactivated on Savannah.
 
   if ($project->Uses("forum")) {
     specific_makesep();
@@ -410,32 +411,68 @@ if ($project->Uses("patch") ||
   $i = 1;
   $j = $i;
 
-  # CVS
-
-  if (($project->getUrl("cvs_viewcvs") != 'http://' && $project->getUrl("cvs_viewcvs") != '' && $project->Uses("cvs")) || ($project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '' && $project->Uses("homepage")))
+  # SCMs
+  #  - check if the SCM is selected by the project
+  #  - check if the SCM is the default SCM, if the project use the standard
+  #    webpage
+  if ($project->Uses("cvs") || $project->UsesForHomepage("cvs"))
     {
       
       $url = $project->getArtifactUrl("cvs");
       
       html_image("cvs.png",array('width'=>'24', 'height'=>'24', 'alt'=>'CVS'));
       print '&nbsp;<a href="'.$url.'">'._("Source Code Manager: CVS Repository").'</a>';
-
-      if ($project->getUrl("cvs_viewcvs") != 'http://' && $project->getUrl("cvs_viewcvs") != '' && $project->Uses("cvs"))
+      if ($project->Uses("cvs") && $project->getUrl("cvs_viewcvs") != 'http://' && $project->getUrl("cvs_viewcvs") != '')
 	{
 	  print '<br /> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs").'">'._("Browse Sources Repository").'</a>';
 	}
-      if ($project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '' && $project->Uses("homepage"))
+      if ($project->UsesForHomepage("cvs") && $project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '')
 	{
-	  # Consider that this link is valid if not empty or not 'http:#'
-	  # (default).
-	  # Only the backend should make use of the is_homepage_on_cvs value,
-	  # because and homepage can be on CVS with this flag off: this flag
-	  # is used to determine whether a CVSROOT must be created or not
 	  print '<br /> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs_homepage").'">'._("Browse Web Pages Repository").'</a>';
 	}
       $i++;
     }
 
+  if ($project->Uses("arch") || $project->UsesForHomepage("arch"))
+    {
+      specific_makesep();
+      $url = $project->getArtifactUrl("arch");
+      
+      html_image("cvs.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Arch'));
+      print '&nbsp;<a href="'.$url.'">'._("Source Code Manager: GNU Arch Repository").'</a>';
+
+      if ($project->Uses("arch") && $project->getUrl("arch_viewcvs") != 'http://' && $project->getUrl("arch_viewcvs") != '')
+	{
+	  print '<br /> &nbsp; - <a href="'.$project->getUrl("arch_viewcvs").'">'._("Browse Sources Repository").'</a>';
+	}
+      if ($project->UsesForHomepage("arch") && $project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '')
+	{
+	  print '<br /> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs_homepage").'">'._("Browse Web Pages Repository").'</a>';
+	}
+      $i++;
+    }
+
+  if ($project->Uses("svn") || $project->UsesForHomepage("svn"))
+    {
+      specific_makesep();
+      $url = $project->getArtifactUrl("svn");
+      
+      html_image("cvs.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Arch'));
+      print '&nbsp;<a href="'.$url.'">'._("Source Code Manager: Subversion Repository").'</a>';
+
+      if ($project->Uses("svn") && $project->getUrl("svn_viewcvs") != 'http://' && $project->getUrl("svn_viewcvs") != '')
+	{
+	  print '<br /> &nbsp; - <a href="'.$project->getUrl("svn_viewcvs").'">'._("Browse Sources Repository").'</a>';
+	}
+      if ($project->UsesForHomepage("svn") && $project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '')
+	{
+	  print '<br /> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs_homepage").'">'._("Browse Web Pages Repository").'</a>';
+	}
+      $i++;
+    }
+
+
+
   # Bug tracking
 
   if ($project->Uses("bugs")) {
