@@ -2,10 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.13 2004/11/24 09:19:47 yeupou Exp $
+# $Id: general.php,v 1.14 2005/03/21 12:03:47 yeupou Exp $
 #
-#  Copyright 2003-2004 (c) Stphane Urbanovski <s.urbanovski@ac-nancy-metz.fr>
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2005 (c) Stphane Urbanovski <s.urbanovski--ac-nancy-metz.fr>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -59,7 +59,8 @@ function search_box ($searched_words='', $only_artifact=0, $size=15, $class="")
     }
   else
     {
-      print ' '._("in").' <select name="type_of_search">';
+      # in with <i> </i> because it is latin, not english.
+      print ' '._("<i>in</i>").' <select name="type_of_search">';
 
       print '<option value="soft"'.(($type_of_search == "soft")||($type_of_search == "") ? ' selected="selected"' : "").'>'._("Project/Group")."</option>\n";
 
