@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: data.php,v 1.22 2004/11/29 07:36:15 yeupou Exp $
+# $Id: data.php,v 1.26 2005/03/21 16:57:03 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-#                          Yves Perrin <yves.perrin--at--cern.ch>
+#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
 # This program is free software; you can redistribute it and/or
@@ -514,6 +514,20 @@ function trackers_data_get_field_predefined_values ($field, $group_id=false, $ch
 
 }
 
+function trackers_data_use_field_predefined_values ($field, $group_id)
+{
+  # Check whether a group field values are the default one or not.
+  # If no entry in the database for the relevant field value belong to the
+  # group, then it uses default values (fallback)
+  $field_id = trackers_data_get_field_id($field);
+  $sql="SELECT bug_fv_id FROM ".ARTIFACT."_field_value ".
+             "WHERE group_id=".$group_id." AND bug_field_id=$field_id";
+
+  $result = db_query($sql);
+  return db_numrows($result);
+}
+
+
 function trackers_data_is_custom($field, $by_field_id=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_is_custom($field, $by_field_id=false)';
@@ -1470,19 +1484,6 @@ function trackers_data_handle_update ($group_id,
       dbg("no management/techn. rights");
       exit_permission_denied();
     }
-
-  # DEPRECATED: the form_id method should make this useless, see
-  #    task #1049 for more details
-  # Check whether this is not a duplicate. This test is clumsy, to avoid
-  # overcomplication, it just make sure the comment is not exactly the
-  # same as the previous one posted for the item.
-  #$previous_comment = db_result(db_query("SELECT old_value FROM ".ARTIFACT."_history WHERE field_name='details' AND bug_id='$item_id' ORDER BY bug_history_id DESC LIMIT 1"), 0, 'old_value');
-  #dbg("PREV: ".$previous_comment." CURRENT: ".$vfl['details']);
-  #if ($vfl['details'] != '' && stripslashes($vfl['details']) == $previous_comment)
-  #  {
-  #    exit_error(_("Duplicate post: the previous comment posted on this item got exactly the same content."));
-  #  }
-
   
   # Extract field transitions possibilities:
   $field_transition = array();
@@ -1558,8 +1559,15 @@ function trackers_data_handle_update ($group_id,
       else if (trackers_data_is_date_field($field))
 	{
 	  # if it's a date we must convert the format to unix time
+          $date_value = $value;
 	  list($value,$ok) = utils_date_to_unixtime($value);
-	  $differ = ($old_value != $value);
+
+          # Users can be on different timezone ; The form
+          # save only the day, month, year.
+          # We cannot compare the timestamp (affected by timezone changes)
+          $date_old_value = date("Y-n-j", $old_value);
+          
+	  $differ = ($date_old_value != $date_value);
 	}
       else
 	{
@@ -1685,6 +1693,9 @@ function trackers_data_handle_update ($group_id,
 	  while (list(, $dep) = each($$dependent_on))
 	    {
 	      trackers_data_update_dependent_items($dep, $item_id, $art);
+
+              $changes['Depends on']['add'] = $art." #".$dep;
+
 	      # Check if we're supposed to send all modifications to an address
 	      list($address, $sendall) = trackers_data_get_item_notification_info($dep, $art, 1);
 	      if (($sendall == 1) && (trim($address) != ""))
@@ -2012,40 +2023,6 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
   if (trackers_check_empty_fields($vfl) == false)
     { exit_error("Exiting"); }
 
-
-  # DEPRECATED: the form_id method should make this useless, see
-  #    task #1049 for more details
-  # first make sure this wasn't double-submitted
-  # we look for a bug with the same summary and group_id
-  # if we found one, we double check with details and submitted_by.
-#   $is_duplicate = db_result(db_query("SELECT bug_id FROM ".ARTIFACT.
-# 				     " WHERE summary='".
-# 				     htmlspecialchars($vfl['summary']).
-# 				     "' AND group_id='".
-# 				     $group_id.
-# 				     "'"),
-# 			    0,
-# 			    'bug_id');
-#
-#   if ($is_duplicate)
-#     {
-#       $is_duplicate = db_result(db_query("SELECT bug_id FROM ".ARTIFACT.
-# 					 " WHERE bug_id='".
-# 					 $is_duplicate.
-# 					 "' AND details='".
-# 					 htmlspecialchars($vfl['details']).
-# 					 "' AND submitted_by='".
-# 					 $user.
-# 					 "'"),
-# 				0,
-# 				'bug_id');
-#     }
-#
-#   if ($is_duplicate)
-#     {
-#       exit_error(_("Error - Duplicated submission: this item already exists in our database."), 1);
-#     }
-
   # Finally, create the bug itself
   # Remark: this SQL query only sets up the values for fields used by
   # this project. For other unused fields we assume that the DB will set
@@ -2061,7 +2038,7 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
 
   # build the variable list of fiels and values
   reset($vfl);
-  while ( list($field,$value) = each($vfl))
+  while (list($field,$value) = each($vfl))
     {
       if (trackers_data_is_special($field))
 	{ continue; }
@@ -2133,6 +2110,7 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
       trackers_field_display($field,$group_id,$old_value,false,false,true,true);
       $changes[$field]['add']=
       trackers_field_display($field,$group_id,$value,false,false,true,true);
+
       # Register transition id 
       $field_transition_accepted[] = $field_transition_id;
 
@@ -2153,7 +2131,7 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
 
   if (!$item_id)
     {
-      fb(_("INSERT new bug failed, Report to the Administrator"), 1);
+      fb(_("New item insertion failed, please report this issue to the administrator"), 1);
     }
 
 
