@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: format.php,v 1.14 2004/11/25 16:14:59 yeupou Exp $
+# $Id: format.php,v 1.17 2005/03/23 08:17:48 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Yves Perrin <yves.perrin--at--cern.ch>
 #
 # This program is free software; you can redistribute it and/or
@@ -61,7 +61,6 @@ function format_item_details ($item_id, $group_id, $ascii=false)
       $title_arr=array();
       $title_arr[]=_("Comment");
       $title_arr[]=_("Posted By");
-      $title_arr[]=_("Date");
 	
       $out .= html_build_list_table_top ($title_arr);
     }
@@ -88,8 +87,8 @@ function format_item_details ($item_id, $group_id, $ascii=false)
 	}
       else
 	{
-	  $fmt = "\n".'<tr class="%s"><td>%s%s</td>'.
-	     '<td valign="top" align="center">%s</td><td valign="top" align="center">%s</td></tr>';
+	  $fmt = "\n".'<tr class="%s"><td valign="top"><a name="%s" href="#%s" class="preinput">%s, %s</a>%s%s</td>'.
+	     '<td valign="top" align="center">%s</td></tr>';
 	}
 	
       # I wish we had sprintf argument swapping in PHP3 but
@@ -117,13 +116,18 @@ function format_item_details ($item_id, $group_id, $ascii=false)
 	    {
 	      # put the comment type in bold
 	      $comment_type = '<font class="bold">'.$comment_type.'</font><br />';
-	    }
+	    } 
+
+          $comment_number = ($rows-$i);
 	  $out .= sprintf($fmt,
 			  utils_get_alt_row_color($i),
+                          "comment".$comment_number,
+                          "comment".$comment_number,
+                          format_date($sys_datefmt,db_result($result, $i, 'date')),
+                          sprintf(_("comment #%s:"), $comment_number),
 			  $comment_type,
-			  '<p>'.utils_make_links(nl2br(db_result($result, $i, 'old_value')),$group_id).'<p>',
-			  utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname')),
-			  format_date($sys_datefmt,db_result($result, $i, 'date')));
+			  '<p>'.utils_make_links(nl2br(db_result($result, $i, 'old_value')),$group_id).'</p><br />',
+			  utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname')));
 ;
 	}
     }
@@ -136,7 +140,7 @@ function format_item_details ($item_id, $group_id, $ascii=false)
 
 
 
-function format_item_changes ($changes)
+function format_item_changes ($changes,$item_id,$group_id)
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':format_item_changes ($changes)';
 
@@ -145,74 +149,90 @@ function format_item_changes ($changes)
 
   global $sys_datefmt;
 
-  reset($changes);
   # FIXME: strange, with %25s it does not behave exactly like
   # trackers_field_label_display
-  $fmt = "%24s: %23s -> %-23s\n";
+  $fmt = "%24s: %23s => %-23s\n";
 
-  if (user_isloggedin())
-    {
-      $user_id = user_getid();
-      $out_hdr = sprintf("%25s", "Posted by:").' '.user_getrealname($user_id).' <'.user_getname($user_id).">\n";
-      $out_hdr .= sprintf("%25s", "Posted on:").' '.format_date("Y-m-j H:i", time()).' ('.user_get_timezone().')';
-    }
-  else
-    {
-      $out_hdr = sprintf("%25s", "Posted by:").' '."an anonymous user\n";
-      $out_hdr .= sprintf("%25s", "Posted on:").' '.format_date("Y-m-j H:i", time()).' ('.user_get_timezone().')';
-    }
+  $separator = "\n    _______________________________________________________\n\n";
 
-  #Process special cases first: follow-up comment
-  if ($changes['details'])
-    {
-      $out_com = "\n    _______________________________________________________\n\nFollow-up Comment:\n";
-      if ($changes['details']['type'] != 'None' && $changes['details']['type'] != '(Error - Not Found)')
-	{
-	  $out_com .= '['.$changes['details']['type']."]\n";
-	}
-      $out_com .= utils_unconvert_htmlspecialchars($changes['details']['add']);
-      unset($changes['details']);
-    }
-
-  #Process special cases first: bug file attachment
-  if ($changes['attach'])
-    {
-      $out_att = "\n    _______________________________________________________\n\nAdditional Item Attachment:\n";
-      $out_att .= sprintf("File name: %-30s Size:%d KB\n",$changes['attach']['name'],
-			  intval($changes['attach']['size']/1024) );
-      $out_att .= $changes['attach']['description']."\n".'<'.$changes['attach']['href'].'>';
-      unset($changes['attach']);
-    }
-
-  # All the rest of the fields now
+  # Process most of the fields
   reset($changes);
-  while ( list($field,$h) = each($changes))
+  while (list($field,$h) = each($changes))
     {
 
       # If both removed and added items are empty skip - Sanity check
       if (!$h['del'] && !$h['add'])
 	{ continue; }
 
+      if ($field == "details" || $field == "attach") 
+        { continue; }
+     
       $label = trackers_data_get_label($field);
       if (!$label)
 	{ $label = $field; }
       $out .= sprintf($fmt, $label, $h['del'],$h['add']);
     }
+
   if ($out)
     {
-      $out = "\n    _______________________________________________________\n\n".$out;
+      $out = "Update of ".utils_get_tracker_prefix(ARTIFACT)." #".$item_id." (project ".group_getunixname($group_id)."):\n\n".$out;
     }
 
-  return($out_hdr.$out.$out_com.$out_att);
+
+  # Process special cases: follow-up comments
+  if ($changes['details'])
+    {
+
+      if ($out)
+        { $out .= $separator; }
+
+      $out_com = "Follow-up Comment #".db_numrows(trackers_data_get_followups($item_id));
+      if (!$out)
+        { 
+          $out_com .= ", ".utils_get_tracker_prefix(ARTIFACT)." #".$item_id." (project ".group_getunixname($group_id).")";
+        }
+
+      $out_com .= ":\n\n";
+      if ($changes['details']['type'] != 'None' && $changes['details']['type'] != '(Error - Not Found)')
+	{
+	  $out_com .= '['.$changes['details']['type']."]\n";
+	}
+      $out_com .= utils_unconvert_htmlspecialchars($changes['details']['add']);
+      unset($changes['details']);
+
+      $out .= $out_com;
+    }
+
+
+  # Process special cases: file attachment
+  if ($changes['attach'])
+    {
+      if ($out)
+        { $out .= $separator; }
+
+      $out_att = "Additional Item Attachment";
+      if (!$out)
+        { 
+          $out_att .= ", ".utils_get_tracker_prefix(ARTIFACT)." #".$item_id." (project ".group_getunixname($group_id).")";
+        }
+      $out_att .= ":\n\n";
+      $out_att .= sprintf("File name: %-30s Size:%d KB\n",$changes['attach']['name'],
+			  intval($changes['attach']['size']/1024) );
+      $out_att .= $changes['attach']['description']."\n".'<'.$changes['attach']['href'].'>';
+      unset($changes['attach']);
+
+      $out .= $out_att;
+    }
+
+  return $out;
 
 }
 
 
 function format_item_attached_files ($item_id,$group_id,$ascii=false)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':format_item_attached_files ($item_id,$group_id,$ascii=false)';
 
-  global $sys_datefmt;
+  global $sys_datefmt, $HTML;
 
   # ASCII must not be translated
 
@@ -240,19 +260,8 @@ function format_item_attached_files ($item_id,$group_id,$ascii=false)
     }
   else
     {	
-	
-      $title_arr=array();
-      $title_arr[]=_("Name");
-      $title_arr[]=_("Description");
-      $title_arr[]=_("Size");
-      $title_arr[]=_("Added By");
-      $title_arr[]=_("Date");
-      if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2'))
-	{
-	  $title_arr[]='Delete?';
-	}
 
-      $out .= html_build_list_table_top ($title_arr);
+      $out .= $HTML->box_top(_("Attached Files"),'',1);
     }
 
   # Determine what the print out format is based on output type (Ascii, HTML
@@ -261,11 +270,6 @@ function format_item_attached_files ($item_id,$group_id,$ascii=false)
       $fmt = "\n-------------------------------------------------------\n".
 	 "Date: %s  Name: %s  Size: %s   By: %s\n%s\n%s";
     }
-  else
-    {
-      $fmt = "\n".'<TR class="%s"><td>%s</td><td>%s</td><td align="center">%s</td><td align="center">%s</td><td align="center">%s</td>'.
-	 (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2') ? '<td align="center">%s</td>':'').'</tr>';
-    }
 
   # Loop throuh the attached files and format them
   for ($i=0; $i < $rows; $i++)
@@ -293,21 +297,32 @@ function format_item_attached_files ($item_id,$group_id,$ascii=false)
 	}
       else
 	{
-	  $out .= sprintf($fmt,
-			  utils_get_alt_row_color($i),
-			  "<a href=\"$href\">". db_result($result, $i, 'filename').'</a>',
-			  db_result($result, $i, 'description'),
-			  utils_filesize(0, intval(db_result($result, $i, 'filesize'))),
-			  utils_user_link(db_result($result, $i, 'user_name')),
-			  format_date($sys_datefmt,db_result($result, $i, 'date')),
-			  "<a href=\"$PHP_SELF?func=delete_file&amp;item_id=$item_id&amp;item_file_id=$item_file_id\" ".
-			  '" onClick="return confirm(\''._("Delete this attachment?").'\')">'.
-			  '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Delete").'" /></a>');
+	  if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2')) 
+	    {
+	      $html_delete = '<span class="trash"><a href="'.$PHP_SELF.'?func=delete_file&amp;item_id='.$item_id.'&amp;item_file_id='.$item_file_id.'">'.
+		'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" class="icon" alt="'._("Delete").'" /></a></span>';
+	    }
+	  else
+	    {
+	      $html_delete = '';
+	    }
+	  
+          $out .= '<li class="'.utils_get_alt_row_color($i).'">'.$html_delete.
+	    '<a href="'.$href.'">file #'.$item_file_id.'</a>'._(": ").'&nbsp;'.sprintf(_('%s added by %s'), '<a href="'.$href.'">'.db_result($result, $i, 'filename').'</a>', utils_user_link(db_result($result, $i, 'user_name')));
+
+	  $out .= ' <font class="smaller">('.utils_filesize(0, intval(db_result($result, $i, 'filesize')));
+	  
+	  if (db_result($result, $i, 'description'))
+	    {
+	      $out .= ' - '.utils_make_links(db_result($result, $i, 'description'));
+	    }
+	  $out .= ')</font>';							    
+	  
 	}
     }
 
   # final touch...
-  $out .= ($ascii ? "\n" : "</table>");
+  $out .= ($ascii ? "\n" : $HTML->box_bottom(1));
 
   return($out);
 
@@ -317,11 +332,8 @@ function format_item_attached_files ($item_id,$group_id,$ascii=false)
 
 function format_item_cc_list ($item_id,$group_id, $ascii=false)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':format_item_cc_list ($item_id,$group_id, $ascii=false)';
-
-  # ASCII must not be translated
-
-  global $sys_datefmt;
+# ASCII must not be translated
+  global $sys_datefmt, $HTML;
 
   /*
           show the files attached to this bug
@@ -355,16 +367,7 @@ function format_item_cc_list ($item_id,$group_id, $ascii=false)
     }
   else
     {	
-
-      $title_arr=array();
-      $title_arr[]=_('CC Mail Address');
-      $title_arr[]=_('Comment');
-      $title_arr[]=_('Added by');
-      $title_arr[]=_('Date');
-      $title_arr[]=_('Delete?');
-      $out .= html_build_list_table_top ($title_arr);
-      $fmt = "\n".'<tr class="%s"><td>%s</td><td>%s</td><td align="center">%s</td>'.
-	 '<td align="center">%s</td><td align="center">%s</td></tr>';
+      $out .= $HTML->box_top(_("Carbon-Copy List"),'',1);
     }
 
   # Loop through the cc and format them
@@ -390,36 +393,38 @@ function format_item_cc_list ($item_id,$group_id, $ascii=false)
 	{
 
 	  # show CC delete icon if one of the condition is met:
-	  # a) current user is a bug admin
+	  # a) current user is a tracker manager
 	  # b) then CC name is the current user 
 	  # c) the CC email address matches the one of the current user
-	  # d) the current user is the person who added a gieven name in CC list
+	  # d) the current user is the person who added a given name in CC list
 	  if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2') ||
-	       (user_getname(user_getid()) == $email) ||  
-	       (user_getemail(user_getid()) == $email) ||
-	       (user_getname(user_getid()) == db_result($result, $i, 'user_name') ))
-	    {
-	      $html_delete = "<a href=\"$PHP_SELF?func=delete_cc&amp;item_id=$item_id&amp;item_cc_id=$item_cc_id\" ".
-		 '" onClick="return confirm(\''._("Delete this CC address?").'\')">'.
-		 '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Delete").'" /></a>';
+	      (user_getname(user_getid()) == $email) ||  
+	      (user_getemail(user_getid()) == $email) ||
+	      (user_getname(user_getid()) == db_result($result, $i, 'user_name') ))
+            {
+$html_delete = '<span class="trash"><a href="'.$PHP_SELF.'?func=delete_cc&amp;item_id='.$item_id.'&amp;item_cc_id='.$item_cc_id.'">'.
+		 '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" class="icon" alt="'._("Delete").'" /></a></span>';
 	    }
 	  else
 	    {
-	      $html_delete = '-';
+	      $html_delete = '';
 	    }
+            
+          $out .= '<li class="'.utils_get_alt_row_color($i).'">'.$html_delete.
+	  sprintf(_('%s added by %s'), $email, utils_user_link(db_result($result, $i, 'user_name')));
+          if (db_result($result, $i, 'comment'))
+           {
+	     $out .= ' <font class="smaller">('.utils_make_links(db_result($result, $i, 'comment')).')</font>';
+           }
 
-	  $out .= sprintf($fmt,
-			  utils_get_alt_row_color($i),
-			  $href_cc,
-			  db_result($result, $i, 'comment'),
-			  utils_user_link(db_result($result, $i, 'user_name')),
-			  format_date($sys_datefmt,db_result($result, $i, 'date')),
-			  $html_delete);
-	}
+#$href_cc,
+#			  format_date($sys_datefmt,db_result($result, $i, 'date')),
+#			  $html_delete);
+        }
     }
 
   # final touch...
-  $out .= ($ascii ? "\n" : "</table>");
+  $out .= ($ascii ? "\n" : $HTML->box_bottom(1));
 
   return($out);
 
