@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: show.php,v 1.17 2004/11/22 08:25:50 yeupou Exp $
+# $Id: show.php,v 1.20 2005/03/21 14:27:15 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
 #
 #
 # This program is free software; you can redistribute it and/or
@@ -399,19 +399,17 @@ function show_dependent_item ($item_id, $dependson=0)
   $rows = array();
   $is_manager = member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'1');
   
-  print '<font class="preinput">';
   if (!$dependson) 
-    { print _("Item(s) that depend on this one:"); }
+    { $title = _("Items that depend on this one"); }
   else 
-    { print _("Depends on the following item(s):"); }
-  print '</font> ';
+    { $title = _("Depends on the following items"); }
 
   # Slurps the database.
   while (list($num, $art) = each($artifacts)) 
     {
       if (!$dependson) 
 	{
-	  $sql = "SELECT ".$art.".bug_id,".$art.".summary,".$art.".status_id,".$art.".group_id,".$art.".priority,".$art.".privacy,".$art.".submitted_by ".
+	  $sql = "SELECT ".$art.".bug_id,".$art.".summary,".$art.".status_id,".$art.".resolution_id,".$art.".group_id,".$art.".priority,".$art.".privacy,".$art.".submitted_by ".
 	     " FROM ".$art.",".$art."_dependencies ".
 	     " WHERE ".$art.".bug_id=".$art."_dependencies.item_id ".
 	     " AND ".$art."_dependencies.is_dependent_on_item_id='$item_id'".
@@ -419,11 +417,11 @@ function show_dependent_item ($item_id, $dependson=0)
 	}
       else
 	{
-	  $sql = "SELECT ".$art.".bug_id,".$art.".summary,".$art.".status_id,".$art.".group_id,".$art.".priority,".$art.".privacy,".$art.".submitted_by".
+	  $sql = "SELECT ".$art.".bug_id,".$art.".summary,".$art.".status_id,".$art.".resolution_id,".$art.".group_id,".$art.".priority,".$art.".privacy,".$art.".submitted_by".
 	     " FROM ".$art.",".ARTIFACT."_dependencies ".
 	     " WHERE ".$art.".bug_id=".ARTIFACT."_dependencies.is_dependent_on_item_id ".
 	     " AND ".ARTIFACT."_dependencies.item_id='$item_id'".
-	     " AND ".ARTIFACT."_dependencies.is_dependent_on_item_id_artifact='".$art."' ORDER by ".$art.".bug_id";
+	     " AND ".ARTIFACT."_dependencies.is_dependent_on_item_id_artifact='".$art."' ORDER by ".$art.".bug_id ";
 
 	}
   
@@ -437,14 +435,9 @@ function show_dependent_item ($item_id, $dependson=0)
       $rows["task"] > 0 ||
       $rows["patch"] > 0)
     {
-      $title_arr=array();
-      $title_arr[]=_("Item id");
-      $title_arr[]=_("Title");
-      $title_arr[]=_("Group");
-      if ($dependson && $is_manager) 
-	{ $title_arr[]=_("Delete?"); }
-
-      print html_build_list_table_top($title_arr);
+     
+      global $HTML;
+      print $HTML->box_top($title,'',1);
 
       reset($artifacts);
       while (list($num, $art) = each($artifacts)) 
@@ -454,54 +447,53 @@ function show_dependent_item ($item_id, $dependson=0)
 
 	      $link_to_item = $GLOBALS['sys_home'].$art.'/?func=detailitem&amp;item_id='. db_result($result[$art], $i, 'bug_id');
 	      
-	      print '
-  <tr class="'.get_priority_color(db_result($result[$art], $i, 'priority'), db_result($result[$art], $i, 'status_id')).'">';
+	      $dstatus = db_result(db_query("SELECT value FROM ".$art."_field_value WHERE bug_field_id='108' AND (group_id='".db_result($result[$art], $i, 'group_id')."' OR group_id='100') AND value_id='".db_result($result[$art], $i, 'resolution_id')."' ORDER BY bug_fv_id DESC LIMIT 1"), 0, 'value');
 
-	      # Link to the item
-	      print '<td>
+	      
+	      print '
+  <li class="'.get_priority_color(db_result($result[$art], $i, 'priority'), db_result($result[$art], $i, 'status_id')).'">';
+
+	      # Ability to remove a dependency is only given to technician
+	      # level members of a project.
+	      if ($dependson && $is_manager) 
+		{ 
+		  print '<span class="trash"><a href="'.$PHP_SELF.'?func=delete_dependancy&amp;item_id='.$item_id.'&amp;item_depends_on='.db_result($result[$art], $i, 'bug_id').
+		    '&amp;item_depends_on_artifact='.$art.'">'.
+		    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" alt="'._("Delete this dependancy?").'" class="icon" /></a></span>'; 
+		}
+
+              # Link to the item
+	      print '
    	<a href="'.$link_to_item.'">';
 
-	      # Show if the item is closed with an icon
-	      if (db_result($result[$art], $i, 'status_id') != 1)
-		{ print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/ok.png" border="0" alt="'._("Closed Item").'" />'; }
-	      else 
-		{ print'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" border="0" alt="'._("Open Item").'" />'; }
+	      # Show the item type with an icon
+	      print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.utils_get_tracker_icon($art).'.png" class="icon" alt="'.$art.'" />'; 
     
-	      print $art.' #'.db_result($result[$art], $i, 'bug_id');
-
-	      # Mention if the item is closed
-	      if (db_result($result[$art], $i, 'status_id') != 1)
-		{ print _(": Closed"); }
-
-	      print '</a></td>
-        <td><a href="'.$link_to_item.'">';
+	      print utils_get_tracker_prefix($art).' #'.db_result($result[$art], $i, 'bug_id');
 	      
-	      # Print summary only if the item is not private
+	      print '</a> : <a href="'.$link_to_item.'">';	     
+	      
+              # Print summary only if the item is not private
 	      if (db_result($result, $i, 'privacy') == "2" &&
 		  !member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2') &&
 		  db_result($result[$art],$i,'submitted_by') != user_getid()) 
 		{ print _("---- Private ----");	}
 	      else
 		{ print db_result($result[$art], $i, 'summary'); }
+	      print '</a>';
 
-	      print '</a></td>
-        <td>'.group_getname(db_result($result[$art], $i, 'group_id')).'</td>';
-
-	      # Ability to remove a dependency is only given to technician
-	      # level members of a project.
-	      if ($dependson && $is_manager) 
-		{ 
-		  print '<td align="center">';
-		  print '<a href="'.$PHP_SELF.'?func=delete_dependancy&amp;item_id='.$item_id.'&amp;item_depends_on='.db_result($result[$art], $i, 'bug_id').
-		    '&amp;item_depends_on_artifact='.$art.
-		    '" onClick="return confirm(\''._("Delete this dependancy?").'\')">'.
-		    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Delete").'" /></a>';
-		  print '</td>';
+	      if (db_result($result[$art], $i, 'group_id') != $group_id)
+		{
+		  print ', '.group_getname(db_result($result[$art], $i, 'group_id'));
 		}
-	      print '</tr>';
+		  
+              # Mention the status
+	      print '&nbsp;<font class="smaller">['.$dstatus.']</font>';
+
+	      print '</li>';
 	    }
 	} 
-      print '</table>';
+      print $HTML->box_bottom(1);
       
      # Link to digest dependant items
       if ($dependson) 
