@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: field_values.php,v 1.21 2004/11/22 08:25:50 yeupou Exp $
+# $Id: field_values.php,v 1.22 2005/03/21 16:57:03 yeupou Exp $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-#                          Yves Perrin <yves.perrin--at--cern.ch>
+#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
 # This program is free software; you can redistribute it and/or
@@ -49,15 +49,15 @@ if ($group_id && user_ismember($group_id,'A'))
     }
   elseif ($post_changes || $delete_canned)
     {
-    # A form of some sort was posted to update or create
-    # an existing value
+# A form of some sort was posted to update or create
+# an existing value
 	
-	# Deleted Canned doesn't need a forum, so let switch
-	# into this code
+# Deleted Canned doesnt need a forum, so let switch
+# into this code
 	
       if ($create_value)
 	{
-          # A form was posted to update a field value
+# A form was posted to update a field value
 	  if ($value)
 	    {
 	      trackers_data_create_value($field,$group_id,
@@ -73,7 +73,7 @@ if ($group_id && user_ismember($group_id,'A'))
 	}
       else if ($update_value)
 	{
-          # A form was posted to update a field value
+# A form was posted to update a field value
 	  if ($value)
 	    {
 	      trackers_data_update_value($fv_id, $field, $group_id,
@@ -90,10 +90,10 @@ if ($group_id && user_ismember($group_id,'A'))
       else if ($create_canned)
 	{
 
-          # A form was posted to create a canned response
+# A form was posted to create a canned response
 	  $sql="INSERT INTO ".ARTIFACT."_canned_responses (group_id,title,body,order_id) ".
-	     " VALUES ('$group_id','". htmlspecialchars($title) .
-	     "','". htmlspecialchars($body) ."','".addslashes($order_id)."')";
+	    " VALUES ('$group_id','". htmlspecialchars($title) .
+	    "','". htmlspecialchars($body) ."','".addslashes($order_id)."')";
 	  $result=db_query($sql);
 	  if (!$result)
 	    {
@@ -107,10 +107,10 @@ if ($group_id && user_ismember($group_id,'A'))
 	}
       else if ($update_canned)
 	{
-          # A form was posted to update a canned response
+# A form was posted to update a canned response
 	  $sql="UPDATE ".ARTIFACT."_canned_responses ".
-	     "SET title='". htmlspecialchars($title) ."', body='". htmlspecialchars($body)."', order_id='".addslashes($order_id)."'".
-	     " WHERE group_id='$group_id' AND bug_canned_id='$item_canned_id'";
+	    "SET title='". htmlspecialchars($title) ."', body='". htmlspecialchars($body)."', order_id='".addslashes($order_id)."'".
+	    " WHERE group_id='$group_id' AND bug_canned_id='$item_canned_id'";
 	  $result=db_query($sql);
 	  if (!$result)
 	    {
@@ -121,40 +121,40 @@ if ($group_id && user_ismember($group_id,'A'))
 	      fb(_("Canned bug response updated"));
 	    }
 	}
-		# Delete Response
-		else if ($_GET['delete_canned'] == '1')
+# Delete Response
+      else if ($_GET['delete_canned'] == '1')
 	{
-		$sql="DELETE FROM ".ARTIFACT."_canned_responses ".
-		"WHERE group_id='".addslashes($group_id)."' AND bug_canned_id='".addslashes($item_canned_id)."'";
-		$result=db_query($sql);
-		if (!$result) {
-			fb(_("Error deleting canned bug response"),1);
-		}
-		else
-		{
-			fb(_("Canned bug response deleted"));
-		}
+	  $sql="DELETE FROM ".ARTIFACT."_canned_responses ".
+	    "WHERE group_id='".addslashes($group_id)."' AND bug_canned_id='".addslashes($item_canned_id)."'";
+	  $result=db_query($sql);
+	  if (!$result) {
+	    fb(_("Error deleting canned bug response"),1);
+	  }
+	  else
+	    {
+	      fb(_("Canned bug response deleted"));
+	    }
+	}
     }
-}
   
   $field_id = ($by_field_id ? $field : trackers_data_get_field_id($field));
 
    
   if ($to != $from) {
-    # A form was posted to update or create a transition
+# A form was posted to update or create a transition
     $sql="SELECT from_value_id,to_value_id,is_allowed,notification_list ".
-       "FROM trackers_field_transition ".
-       "WHERE group_id='$group_id' AND artifact='".ARTIFACT."' AND field_id='$field_id' AND from_value_id='$from' AND to_value_id='$to' ";
+      "FROM trackers_field_transition ".
+      "WHERE group_id='$group_id' AND artifact='".ARTIFACT."' AND field_id='$field_id' AND from_value_id='$from' AND to_value_id='$to' ";
     $res_value = db_query($sql);
     $rows=db_numrows($res_value);
     
-    # If no entry for this transition, create one
+# If no entry for this transition, create one
     if ($rows == 0)
       {
 	
 	$sql = "INSERT INTO  trackers_field_transition ".
-	   "(group_id,artifact,field_id,from_value_id,to_value_id,is_allowed,notification_list) ".
-	   "VALUES ('$group_id','".ARTIFACT."','$field_id','$from','$to','$allowed','$mail_list')";
+	  "(group_id,artifact,field_id,from_value_id,to_value_id,is_allowed,notification_list) ".
+	  "VALUES ('$group_id','".ARTIFACT."','$field_id','$from','$to','$allowed','$mail_list')";
 	$result = db_query($sql);
  
 	if (db_affected_rows($result) < 1)
@@ -164,10 +164,10 @@ if ($group_id && user_ismember($group_id,'A'))
       }
     else
       {
-        # update the existing entry for this transition
+# update the existing entry for this transition
 	$sql = "UPDATE trackers_field_transition ".
-	   "SET is_allowed='$allowed',notification_list='$mail_list' ".
-	   "WHERE group_id='$group_id' AND artifact='".ARTIFACT."' AND field_id='$field_id'  AND from_value_id='$from' AND to_value_id='$to' ";
+	  "SET is_allowed='$allowed',notification_list='$mail_list' ".
+	  "WHERE group_id='$group_id' AND artifact='".ARTIFACT."' AND field_id='$field_id'  AND from_value_id='$from' AND to_value_id='$to' ";
 	$result = db_query($sql);
 
 	if (db_affected_rows($result) < 1)
@@ -193,7 +193,7 @@ if ($group_id && user_ismember($group_id,'A'))
 
       trackers_header_admin(array ('title'=>$hdr));
 
-      print '<h2>'._("Field Label:").' '.trackers_data_get_label($field).' &nbsp;&nbsp; <font class="smaller">['.utils_link($GLOBALS['sys_home'].ARTIFACT.'/admin/field_usage.php?group='.$group_name.'&amp;update_field=1&amp;field='.$field, _("Jump to this field usage"))."]</font></h2>\n";
+      print '<h2>'._("Field Label:").' '.trackers_data_get_label($field).' &nbsp;&nbsp; <font class="smaller">('.utils_link($GLOBALS['sys_home'].ARTIFACT.'/admin/field_usage.php?group='.$group_name.'&amp;update_field=1&amp;field='.$field, _("Jump to this field usage")).")</font></h2>\n";
 
 
 
@@ -252,7 +252,7 @@ if ($group_id && user_ismember($group_id,'A'))
 		  if (!$is_project_scope)
 		    !$html .='<td>'.$value_id.'</td>';
 
-# The permanent values can't be modified (No link)
+# The permanent values cant be modified (No link)
 		  if ($status == 'P')
 		    {
 		      $html .= '<td>'.$value.'</td>';
@@ -260,41 +260,41 @@ if ($group_id && user_ismember($group_id,'A'))
 		  else
 		    {
 		      $html .= '<td><a href="'.$PHP_SELF.'?update_value=1'.
-			 '&fv_id='.$item_fv_id.'&field='.$field.
-		      '&group_id='.$group_id.'">'.$value.'</A></td>';
+			'&fv_id='.$item_fv_id.'&field='.$field.
+			'&group_id='.$group_id.'">'.$value.'</A></td>';
 		    }
 		    
-		   $html .= '<td>'.$description.'&nbsp;</td>'.
-                        '<td align="center">'.$order_id.'</td>'.
-                        '<td align="center">'.$status_stg[$status].'</td>';
+		  $html .= '<td>'.$description.'&nbsp;</td>'.
+		    '<td align="center">'.$order_id.'</td>'.
+		    '<td align="center">'.$status_stg[$status].'</td>';
 
 		  if ($status == 'H' && $usage > 0)
-                   {
-                     $html .= '<td align="center"><b class="warn">'.$usage.'</b></td>';
-                   }
+		    {
+		      $html .= '<td align="center"><b class="warn">'.$usage.'</b></td>';
+		    }
 		  else
-      {
-	 $html .= '<td align="center">'.$usage.'</td>';
-      }
+		    {
+		      $html .= '<td align="center">'.$usage.'</td>';
+		    }
 
 		  if ($status == 'A' || $status == 'P')
 		    {
 		      $html = '<tr class="'.
-			 utils_get_alt_row_color($ia) .'">'.$html.'</tr>';
+			utils_get_alt_row_color($ia) .'">'.$html.'</tr>';
 		      $ia++;
 		      $ha .= $html;
 		    }
 		  else
 		    {
 		      $html = '<tr class="'.
-			 utils_get_alt_row_color($ih) .'">'.$html.'</tr>';
+			utils_get_alt_row_color($ih) .'">'.$html.'</tr>';
 		      $ih++;
 		      $hh .= $html;
 		    }
 
 		}
 
-	      # Display the list of values now
+# Display the list of values now
 	      if ($ia == 0)
 		{
 		  $hdr = '<p>'._("No Active value for this field. Create one or reactivate a hidden value (if any)").'</p>'.$hdr;
@@ -306,7 +306,7 @@ if ($group_id && user_ismember($group_id,'A'))
 	      if ($ih)
 		{
 		  $hh = '<tr><td colspan="4"> &nbsp;</td></tr>'.
-		     '<tr><td colspan="4"><center><b>'._("---- HIDDEN VALUES ----").'</b></center></tr>'.$hh;
+		    '<tr><td colspan="4"><center><b>'._("---- HIDDEN VALUES ----").'</b></center></tr>'.$hh;
 		}
 
 	      print $hdr.$ha.$hh.'</table>';
@@ -318,7 +318,7 @@ if ($group_id && user_ismember($group_id,'A'))
 	    }
 
 
-	  # Only show the add value form if this is a project scope field
+# Only show the add value form if this is a project scope field
 	  if ($is_project_scope)
 	    {
 
@@ -330,8 +330,8 @@ if ($group_id && user_ismember($group_id,'A'))
 		  print '<p>'._("Before you create a new value make sure there isn't one in the hidden list that suits your needs.").'</p>';
 		}
 
-       # yeupou--gnu.org 2004-09-12: a red star should mention with fields
-       # are mandatory
+# yeupou--gnu.org 2004-09-12: a red star should mention with fields
+# are mandatory
        
 	      print '
       <form action="'.$PHP_SELF.'" method="post">
@@ -360,6 +360,54 @@ if ($group_id && user_ismember($group_id,'A'))
       </form>';
 
 	    }
+	  
+          # If the project use custom values, propose to reset to the default
+	  if (trackers_data_use_field_predefined_values($field,$group_id)) {
+	    
+	    print '<h3>'._("Reset values").'</h3>';
+	    print '<p>'._("You are currently using custom values. If you want to reset values to the default ones, use the following form:").'</p>';
+	    
+	    print '<form action="field_values_reset.php" method="post" class="center">';
+	    print '<input type="hidden" name="group_id" value="'.$group_id.'" />';     
+	    print '<input type="hidden" name="field" value="'.$field.'" />';
+	    print '<input type="submit" name="submit" value="'._("Reset Values").'" /> ';
+	    print '</form>';
+
+
+
+	    print '<p>'._("For your information, the default active values are:").'</p>';
+
+	    $default_result = trackers_data_get_field_predefined_values($field, '100',false,false,false);
+	    $default_rows = db_numrows($default_result);
+	    if ($default_result && $default_rows > 0)
+	      {
+		while ($fld_val = db_fetch_array($default_result))
+		  {
+		    $status = $fld_val['status'];
+		    $value = $fld_val['value'];
+		    $description = $fld_val['description'];
+		    $order = $fld_val['order_id'];
+
+		    # non-active value are not important here
+		    if ($status != "A")
+		      { continue; }
+
+		    if ($previous)
+		      { print ", "; }
+
+		    print '<font class="bold">'.$value.'</font> <font class="smaller">('.$order.', "'.$description.'")</font>';
+		    $previous = 1;
+		  }
+
+	      }
+	    else 
+	      {
+		print '<p class="error">'._("No default values found. You should report this problem to administrators.").'</p>';
+	      }
+
+
+	  }
+	  
 	}
       else
 	{
@@ -370,53 +418,53 @@ if ($group_id && user_ismember($group_id,'A'))
 	}
 
 
-      # Transitions
-      # yeupou--gnu.org 2004-09-12: where the hell is by_field_id set? 
+# Transitions
+# yeupou--gnu.org 2004-09-12: where the hell is by_field_id set? 
       $field_id = ($by_field_id ? $field : trackers_data_get_field_id($field));
       if ( trackers_data_get_field_id($field) &&
            trackers_data_is_select_box($field))
         {
 
-          # First get all the value_id - value pairs
-           $sql="SELECT value_id,value ".
-               "FROM ".ARTIFACT."_field_value ".
-               "WHERE group_id='".addslashes($group_id)."' AND bug_field_id='".addslashes($field_id)."'";
+# First get all the value_id - value pairs
+	  $sql="SELECT value_id,value ".
+	    "FROM ".ARTIFACT."_field_value ".
+	    "WHERE group_id='".addslashes($group_id)."' AND bug_field_id='".addslashes($field_id)."'";
           $res_value = db_query($sql);
           $rows=db_numrows($res_value);
 
           if ($rows > 0) 
             {   
-            $val_label = array();
-            while ($val_row = db_fetch_array($res_value))
-              {
-                $value_id = $val_row['value_id'];
-                $value   = $val_row['value'];
-                $val_label[$value_id] = $value;
-              }
+	      $val_label = array();
+	      while ($val_row = db_fetch_array($res_value))
+		{
+		  $value_id = $val_row['value_id'];
+		  $value   = $val_row['value'];
+		  $val_label[$value_id] = $value;
+		}
             } 
           else 
             {
-            $sql="SELECT value_id,value ".
-                 "FROM ".ARTIFACT."_field_value ".
-                 "WHERE group_id=100 AND bug_field_id='".addslashes($field_id)."'";
-            $res_value = db_query($sql);
-            $rows=db_numrows($res_value);
+	      $sql="SELECT value_id,value ".
+		"FROM ".ARTIFACT."_field_value ".
+		"WHERE group_id=100 AND bug_field_id='".addslashes($field_id)."'";
+	      $res_value = db_query($sql);
+	      $rows=db_numrows($res_value);
 
-            if ($rows > 0) 
-             {
-              $val_label = array();
-              while ($val_row = db_fetch_array($res_value))
-                {
-                  $value_id = $val_row['value_id'];
-                  $value   = $val_row['value'];
-                  $val_label[$value_id] = $value;
-                }
-             }
-          }
+	      if ($rows > 0) 
+		{
+		  $val_label = array();
+		  while ($val_row = db_fetch_array($res_value))
+		    {
+		      $value_id = $val_row['value_id'];
+		      $value   = $val_row['value'];
+		      $val_label[$value_id] = $value;
+		    }
+		}
+	    }
 
           $sql="SELECT transition_id,from_value_id,to_value_id,is_allowed,notification_list ".
-          "FROM trackers_field_transition ".
-          "WHERE group_id='".addslashes($group_id)."' AND artifact='".ARTIFACT."' AND field_id='".addslashes($field_id)."' ";
+	    "FROM trackers_field_transition ".
+	    "WHERE group_id='".addslashes($group_id)."' AND artifact='".ARTIFACT."' AND field_id='".addslashes($field_id)."' ";
 
           $result = db_query($sql);
           $rows = db_numrows($result);
@@ -448,55 +496,55 @@ if ($group_id && user_ismember($group_id,'A'))
                     $allowed = _("No");
                   }
 
-                 print '<tr class="'.utils_altrow($z).'">';
-                 if ($val_label[$transition['from_value_id']])
-                   {
-                     print '<td align="center">'.$val_label[$transition['from_value_id']].'</td>';
-                   }
-                 else
-                   {
-                     print '<td  align="center">'._("* - Any").'</td>'; 
-                   }
+		  print '<tr class="'.utils_altrow($z).'">';
+		  if ($val_label[$transition['from_value_id']])
+		    {
+		      print '<td align="center">'.$val_label[$transition['from_value_id']].'</td>';
+		    }
+		  else
+		    {
+		      print '<td  align="center">'._("* - Any").'</td>'; 
+		    }
 
-                 print '<td align="center">'.$val_label[$transition['to_value_id']].'</td>'
-                       .'<td align="center">'.$allowed.'</td>';
+		  print '<td align="center">'.$val_label[$transition['to_value_id']].'</td>'
+		    .'<td align="center">'.$allowed.'</td>';
 
                   if ($transition['is_allowed'] == 'A') 
-                     {
-		       print '<td align="center">';
-		       # Get list of registered field updates
-		       $registered = trackers_transition_get_other_field_update($transition['transition_id']);
-		       # Make sure $content is clean
-		       unset($content);
-		       # No result? Print only a link
-		       if ($registered)
-			 {
-			   while ($entry = db_fetch_array($registered))
-			     {
-			       # Add one entry per registered other field update
-			       $content .= trackers_data_get_label($entry['update_field_name']).":".trackers_data_get_value($entry['update_field_name'], $group_id, $entry['update_value_id']).", ";
-			     }
-			   # Remove extra comma
-			   $content = trim($content, ", ");
-			 }
-		       else
-			 {
-			   $content = _("Edit others fields update");
-			 }
+		    {
+		      print '<td align="center">';
+# Get list of registered field updates
+		      $registered = trackers_transition_get_other_field_update($transition['transition_id']);
+# Make sure $content is clean
+		      unset($content);
+# No result? Print only a link
+		      if ($registered)
+			{
+			  while ($entry = db_fetch_array($registered))
+			    {
+# Add one entry per registered other field update
+			      $content .= trackers_data_get_label($entry['update_field_name']).":".trackers_data_get_value($entry['update_field_name'], $group_id, $entry['update_value_id']).", ";
+			    }
+# Remove extra comma
+			  $content = trim($content, ", ");
+			}
+		      else
+			{
+			  $content = _("Edit others fields update");
+			}
 
-		       print utils_link($GLOBALS['sys_home'].ARTIFACT."/admin/field_values_transition-ofields-update.php?group=".$group_name."&amp;transition_id=".$transition['transition_id'], $content);
-		       print '</td><td align="center">'.$transition['notification_list'].'</td>';
-                     }
-                    else
-                     {
-                       print '<td align="center">---------</td>'
-                       .'<td align="center">--------</td>';
-                     }
+		      print utils_link($GLOBALS['sys_home'].ARTIFACT."/admin/field_values_transition-ofields-update.php?group=".$group_name."&amp;transition_id=".$transition['transition_id'], $content);
+		      print '</td><td align="center">'.$transition['notification_list'].'</td>';
+		    }
+		  else
+		    {
+		      print '<td align="center">---------</td>'
+			.'<td align="center">--------</td>';
+		    }
                   print '<td align="center">'.utils_link($PHP_SELF.'?group='.$group_name.'&amp;func=deltransition&amp;transition_id='.$transition['transition_id'].'&amp;list_value=1&amp;field='.$field, '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Delete this transition?").'" />').'</td>';
                   print '</tr>';
                 }
                
-                print '</table>';
+	      print '</table>';
             }
           else
             {
@@ -505,7 +553,7 @@ if ($group_id && user_ismember($group_id,'A'))
             }
 
       
-              print '
+	  print '
                      <form action="'.$PHP_SELF.'#registered" method="post">
                      <input type="hidden" name="post_transition_changes" value="y" />
                      <input type="hidden" name="list_value" value="y" />
@@ -513,47 +561,47 @@ if ($group_id && user_ismember($group_id,'A'))
                      <input type="hidden" name="field" value="'.$field.'" />
                      <input type="hidden" name="group_id" value="'.$group_id.'" />';
              
-              if (db_result(db_query("SELECT transition_default_auth FROM ".ARTIFACT."_field_usage WHERE group_id='$group_id' AND bug_field_id='".trackers_data_get_field_id($field)."'"), 0, 'transition_default_auth') == "F")
-                 {
-                    $auth = _("Forbidden");
-                 }
-              else
-                 {
-                   $auth = _("Allowed");
-                 }
-              print "\n\n<p>&nbsp;</p><h3>".html_anchor(_("Create / Edit a transition"),"create").'</h3>';
+	  if (db_result(db_query("SELECT transition_default_auth FROM ".ARTIFACT."_field_usage WHERE group_id='$group_id' AND bug_field_id='".trackers_data_get_field_id($field)."'"), 0, 'transition_default_auth') == "F")
+	    {
+	      $auth = _("Forbidden");
+	    }
+	  else
+	    {
+	      $auth = _("Allowed");
+	    }
+	  print "\n\n<p>&nbsp;</p><h3>".html_anchor(_("Create / Edit a transition"),"create").'</h3>';
 
-              print '<p>'.sprintf(_("By default, for this field, the transitions not registered are %s. This setting can be changed when managing this field usage."),$auth).'</p>';
-              print '<p>'._("Once a transition created, it will be possible to set \"Others Fields Update\" for this transition.").'</p>';
+	  print '<p>'.sprintf(_("By default, for this field, the transitions not registered are %s. This setting can be changed when managing this field usage."),$auth).'</p>';
+	  print '<p>'._("Once a transition created, it will be possible to set \"Others Fields Update\" for this transition.").'</p>';
 
-              $title_arr=array();
-              $title_arr[]=_("From");
-              $title_arr[]=_("To");
-              $title_arr[]=_("Is Allowed");
-              $title_arr[]=_("Carbon-Copy List");
+	  $title_arr=array();
+	  $title_arr[]=_("From");
+	  $title_arr[]=_("To");
+	  $title_arr[]=_("Is Allowed");
+	  $title_arr[]=_("Carbon-Copy List");
 
-              $auth_label = array();
-              $auth_label[] = 'allowed';
-              $auth_label[] = 'forbidden';
-              $auth_val = array();
-              $auth_val[] = 'A';
-              $auth_val[] = 'F';
+	  $auth_label = array();
+	  $auth_label[] = 'allowed';
+	  $auth_label[] = 'forbidden';
+	  $auth_val = array();
+	  $auth_val[] = 'A';
+	  $auth_val[] = 'F';
 
-              $hdr = html_build_list_table_top ($title_arr);
+	  $hdr = html_build_list_table_top ($title_arr);
 
-              $from    = '<td>'.trackers_field_box($field,'from',$group_id,false,false, false, 1, _("* - Any")).'</td>';
-              $to      = '<td>'.trackers_field_box($field,'to',$group_id,false,false).'</td>';
-              print $hdr.'<tr>'.$from.$to;
+	  $from    = '<td>'.trackers_field_box($field,'from',$group_id,false,false, false, 1, _("* - Any")).'</td>';
+	  $to      = '<td>'.trackers_field_box($field,'to',$group_id,false,false).'</td>';
+	  print $hdr.'<tr>'.$from.$to;
 
-              print '<td>'.html_build_select_box_from_arrays ($auth_val,$auth_label,'allowed', 'allowed',false).'</td>';
+	  print '<td>'.html_build_select_box_from_arrays ($auth_val,$auth_label,'allowed', 'allowed',false).'</td>';
 
-              $mlist   = '<td>'.'
+	  $mlist   = '<td>'.'
               <input type="text" name="mail_list" value="" size="30" maxlength="60" />
               </td>';
 
-              print $mlist.'</tr></table>';
+	  print $mlist.'</tr></table>';
 
-              print '<p align="center"><input type="submit" name="submit" value="'._("Update Transition").'" /></p>
+	  print '<p align="center"><input type="submit" name="submit" value="'._("Update Transition").'" /></p>
                      </form>';
         }
       else
@@ -567,12 +615,12 @@ if ($group_id && user_ismember($group_id,'A'))
     }
   else if ($update_value)
     {
-      # Show the form to update an existing field_value
-      # Display the List of values for a given bug field
+# Show the form to update an existing field_value
+# Display the List of values for a given bug field
 
       trackers_header_admin(array ('title'=>_("Update Field Values")));
 
-      # Get all attributes of this value
+# Get all attributes of this value
       $res = trackers_data_get_field_value($fv_id);
 
       print '<form action="'.$PHP_SELF.'" method="post">
@@ -604,10 +652,10 @@ if ($group_id && user_ismember($group_id,'A'))
 
       $count = trackers_data_count_field_value_usage($group_id, $field, db_result($res,0,'value_id'));
       if ($count > 0) 
-       {
-         print '<p class="warn">'.sprintf(_("This field value applies to %s items of your tracker. If you hide this field value, the related items will have no value in the field '%s'."),$count,$field).'</p>';
-       } 
-     print '
+	{
+	  print '<p class="warn">'.sprintf(_("This field value applies to %s items of your tracker. If you hide this field value, the related items will have no value in the field '%s'."),$count,$field).'</p>';
+	} 
+      print '
       <p class="center">
       <input type="submit" name="submit" value="'._("Submit").'" /></p>';
 
@@ -641,8 +689,8 @@ if ($group_id && user_ismember($group_id,'A'))
 
 	  for ($i=0; $i < $rows; $i++)
 	    {
-             # FIXME: delete should use the basket, like it is done in many
-             # other places
+# FIXME: delete should use the basket, like it is done in many
+# other places
 	      print '<tr class="'. utils_get_alt_row_color($i) .'">'.
 		'<td><a href="'.$PHP_SELF.'?update_canned=1&amp;item_canned_id='.
 		db_result($result, $i, 'bug_canned_id').'&amp;group_id='.$group_id.'">'.
@@ -688,23 +736,21 @@ if ($group_id && user_ismember($group_id,'A'))
     }
   else if ($update_canned)
     {
-      #  Allow change of canned responses
+#  Allow change of canned responses
       trackers_header_admin(array ('title'=>_("Modify Canned Response")));
 
       $sql="SELECT bug_canned_id,title,body,order_id FROM ".ARTIFACT."_canned_responses WHERE ".
-	 "group_id='".addslashes($group_id)."' AND bug_canned_id='".addslashes($item_canned_id)."'";
+	"group_id='".addslashes($group_id)."' AND bug_canned_id='".addslashes($item_canned_id)."'";
 
       $result=db_query($sql);
 
       if (!$result || db_numrows($result) < 1)
 	{
-           fb(_("No such response!"),1);
+	  fb(_("No such response!"),1);
 	}
       else
 	{
-	  /*
-	      Escape to print update form
-	  */
+# Escape to print update form
 
 	  print '<p>'
 	    ._("Creating generic messages can save you a lot of time when giving common responses.").'</p>
@@ -732,11 +778,11 @@ if ($group_id && user_ismember($group_id,'A'))
   else
     {
 
-     ######## Complete list of fields
+######## Complete list of fields
 
       trackers_header_admin(array ('title'=>_("Field Values Management")));
 
-      # Loop through the list of all used fields that are project manageable
+# Loop through the list of all used fields that are project manageable
       $i=0;
       $title_arr=array();
       $title_arr[]=_("Field Label");
@@ -764,10 +810,10 @@ if ($group_id && user_ismember($group_id,'A'))
 	    }
 	}
 
-      # Now the special canned response field
+# Now the special canned response field
       print '<tr class="'. utils_get_alt_row_color($i) .'">';
       print "<td><a href=\"$PHP_SELF?group_id=$group_id&amp;create_canned=1\">"._("Canned Responses").'</a></td>';
-      print "\n<td>"._("Create or Change generic quick response messages for the bug tracking tool. Theses pre-written messages can then be used to quickly reply to bug submission.").' </td>';
+      print "\n<td>"._("Create or Change generic quick response messages for this issue tracker. Theses pre-written messages can then be used to quickly reply to item submission.").' </td>';
       print "\n<td>"._("Project").'</td></tr>';
       print '</table>';
     }
@@ -777,7 +823,7 @@ if ($group_id && user_ismember($group_id,'A'))
 }
 else
 {
-  #browse for group first message
+#browse for group first message
   if (!$group_id)
     {
       exit_no_group();
