@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: browse.php,v 1.32 2004/11/25 14:44:27 yeupou Exp $
+# $Id: browse.php,v 1.39 2005/03/24 08:35:06 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-#                          Yves Perrin <yves.perrin--at--cern.ch>
+#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Yves Perrin <yves.perrin--cern.ch>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -36,10 +36,10 @@ if (!$chunksz)
 if ($func == "digest")
 { $digest = 1; }
 else
-{ 
-  $digest = 0; 
+{
+  $digest = 0;
   $func = "browse";
-} 
+}
 
 
 # Make sure offset is defined and has a correct value
@@ -107,7 +107,7 @@ while (list($field,$value_id) = each($prefs))
 #   if morder not defined then reuse the one in preferences
 if (user_isloggedin() && !isset($morder))
 {
-  $morder = user_get_preference('bug_browse_order'.$group_id);
+  $morder = user_get_preference(ARTIFACT.'_browse_order'.$group_id);
 }
 
 if (isset($order))
@@ -130,8 +130,8 @@ if (isset($morder))
 
   if (user_isloggedin())
     {
-      if ($morder != user_get_preference('bug_browse_order'.$group_id))
-	user_set_preference('bug_browse_order'.$group_id, $morder);
+      if ($morder != user_get_preference(ARTIFACT.'browse_order'.$group_id))
+	user_set_preference(ARTIFACT.'_browse_order'.$group_id, $morder);
     }
 
   if ($morder != '')
@@ -152,12 +152,12 @@ if (user_isloggedin())
 {
   if (!isset($report_id))
     {
-      $report_id = user_get_preference('bug_browse_report'.$group_id);
+      $report_id = user_get_preference(ARTIFACT.'_browse_report'.$group_id);
     }
   else
     {
-      if ($report_id != user_get_preference('bug_browse_report'.$group_id))
-	user_set_preference('bug_browse_report'.$group_id, $report_id);
+      if ($report_id != user_get_preference(ARTIFACT.'_browse_report'.$group_id))
+	user_set_preference(ARTIFACT.'_browse_report'.$group_id, $report_id);
     }
 }
 
@@ -182,7 +182,7 @@ if (!$set)
   if (user_isloggedin())
     {
 
-      $custom_pref=user_get_preference('bug_brow_cust'.$group_id);
+      $custom_pref=user_get_preference(ARTIFACT.'_brow_cust'.$group_id);
 
       if ($custom_pref)
 	{
@@ -261,7 +261,7 @@ else if ($set=='custom')
   if ($pref_stg != user_get_preference('bug_brow_cust'.$group_id))
     {
       #print "<br /> DBG setting pref = $pref_stg";
-      user_set_preference('bug_brow_cust'.$group_id,$pref_stg);
+      user_set_preference(ARTIFACT.'_brow_cust'.$group_id,$pref_stg);
     }
 
 }
@@ -320,10 +320,10 @@ while (list($field,$value_id) = each($prefs))
       # Only select box criteria to where clause if argument is not ANY
       $where .= ' AND '.ARTIFACT.'.'.$field.' IN ('.implode(',',$prefs[$field]).') ';
 
-    } 
+    }
   else if (trackers_data_is_date_field($field) && $prefs[$field][0])
     {
-      
+
 # transform a date field into a unix time and use <, > or =
       list($time,$ok) = utils_date_to_unixtime($prefs[$field][0]);
       preg_match("/\s*(\d+)-(\d+)-(\d+)/", $prefs[$field][0],$match);
@@ -333,16 +333,16 @@ while (list($field,$value_id) = each($prefs))
 	{
 	  list($time_end,$ok_end) = utils_date_to_unixtime($prefs[$field.'_end'][0]);
 	  if ($ok)
-	    { 
+	    {
 	      $where .= ' AND '.ARTIFACT.'.'.$field.' >= '. $time; }
-	  
+
 	  if ($ok_end)
 	    { $where .= ' AND '.ARTIFACT.'.'.$field.' <= '. $time_end; }
-	  
+
 	}
       else
 	{
-	  
+
 	  $operator = $prefs[$field.'_op'][0];
           # '=' means that day between 00:00 and 23:59
 	  if ($operator == '=')
@@ -356,16 +356,16 @@ while (list($field,$value_id) = each($prefs))
 	      $where .= ' AND '.ARTIFACT.'.'.$field." $operator= $time ";
 	    }
 	}
-      
+
       # Always exclude undefined dates (0)
       $where .= ' AND '.ARTIFACT.'.'.$field." <> 0 ";
-      
-    } 
+
+    }
   elseif ((trackers_data_is_text_field($field) ||
-	    trackers_data_is_text_area($field)) && 
+	    trackers_data_is_text_area($field)) &&
 	   $prefs[$field][0])
     {
-    
+
       # It s a text field accept. Process INT or TEXT,VARCHAR fields differently
       $where .= ' AND '.trackers_build_match_expression($field, $prefs[$field][0]);
     }
@@ -379,11 +379,11 @@ $ib=0;$is=0;
 $load_cal=false;
 while ($field = trackers_list_all_fields(cmp_place_query))
 {
-  
+
   if (!trackers_data_is_used($field) ||
       !trackers_data_is_showed_on_query($field))
     { continue; }
-  
+
   # beginning of a new row
   if ($ib % $fields_per_line == 0)
     {
@@ -391,7 +391,7 @@ while ($field = trackers_list_all_fields(cmp_place_query))
       $labels .= "\n".'<tr align="'.$align.'" valign="top">';
       $boxes .= "\n".'<tr align="'.$align.'" valign="top">';
     }
-  
+
   $labels .= '<td class="preinput">'.trackers_data_get_label($field).' :</td>';
      # Duh, it never work with konqueror and many others browsers
      # and basically, if "category" is unclear, the name of the field
@@ -407,13 +407,13 @@ while ($field = trackers_list_all_fields(cmp_place_query))
 	 trackers_field_display($field,$group_id,
 				($advsrch ? $prefs[$field] : $prefs[$field][0]),
 				false,false,($printer?true:false),false,true,'None', true,'Any');
-      
-    } 
+
+    }
   else if (trackers_data_is_date_field($field))
     {
-      
+
       if ($advsrch)
-	{ 
+	{
 	  $boxes .= trackers_multiple_field_date($field,$prefs[$field][0],
 						 $prefs[$field.'_end'][0],0,0,$printer);
 	}
@@ -421,28 +421,28 @@ while ($field = trackers_list_all_fields(cmp_place_query))
 	{
 	  $boxes .= trackers_field_date_operator($field,$prefs[$field.'_op'][0],$printer).
 	     trackers_field_date($field,$prefs[$field][0],0,0,$printer);
-	} 
-      
+	}
+
     }
   else if (trackers_data_is_text_field($field) ||trackers_data_is_text_area($field))
     {
 # yeupou--gnu.org 2004-09-17: how can we reach this elseif after an
-# if?	  
+# if?
       $boxes .=
 	 ($printer ? $prefs[$field][0] : trackers_field_text($field,$prefs[$field][0],15,80)) ;
     }
 
   $boxes .= "</TD>\n";
-  
+
   $ib++;
-  
+
 # end of this row
   if ($ib % $fields_per_line == 0)
     {
       $html_select .= $labels.'</TR>'.$boxes.'</TR>';
       $labels = $boxes = '';
     }
-  
+
 }
 
 # Make sure the last few cells are in the table
@@ -475,7 +475,7 @@ while ( $field = trackers_list_all_fields(cmp_place_result))
   $col_list[] = $field;
   $width_list[] = trackers_data_get_col_width($field);
   $lbl_list[] = trackers_data_get_label($field);
-  
+
   if (trackers_data_is_username_field($field))
     {
       # user names requires some special processing to display the username
@@ -527,16 +527,16 @@ else
 if ($browse_preamble)
 { print $browse_preamble; }
 
-print '    <FORM ACTION="'.$PHP_SELF .'" METHOD="GET" NAME="bug_form">
-          <INPUT TYPE="HIDDEN" NAME="group" VALUE="'.$group_name.'">
-          <INPUT TYPE="HIDDEN" NAME="func" VALUE="'.$func.'">
-          <INPUT TYPE="HIDDEN" NAME="set" VALUE="custom">
-          <INPUT TYPE="HIDDEN" NAME="msort" VALUE="'.$msort.'">
+print '    <form action="'.$PHP_SELF .'" method="get" name="bug_form">
+          <input type="hidden" name="group" value="'.$group_name.'">
+          <input type="hidden" name="func" value="'.$func.'">
+          <input type="hidden" name="set" value="custom">
+          <input type="hidden" name="msort" value="'.$msort.'">
           <h3>'._("Browse").' ';
 
 # Show the list of available bug reports kind
 $res_report = trackers_data_get_reports($group_id,user_getid());
-$box_name = 'report_id" onChange="document.bug_form.go_report.click()';
+$box_name = 'report_id"';
 printf(_("with the %s query form"), html_build_select_box($res_report,$box_name,$report_id,true,'Basic'));
 
 # Start building the URL that we use to for hyperlink in the form
@@ -581,7 +581,7 @@ else
     { $advsrch_x = _("Multiple");  }
   else
     { $advsrch_x =  _("Simple");  }
-  
+
   printf(' '._("and %s selection."), $advsrch_x);
 }
 
@@ -596,14 +596,12 @@ print $html_select;
 print '</table>';
 if (!$printer)
 {
-  print '<p><font class="smaller">Show</font> '.
-    '<input type="text" name="chunksz" size="3" maxlength="5" '.
-    'value="'.$chunksz.'"> '._("items at once").'.</form>';
+  print '<p><font class="smaller">'.sprintf(_("Show %s items at once."), '<input type="text" name="chunksz" size="3" maxlength="5" '.
+    'value="'.$chunksz.'" />').'</font></form>';
 }
 else
 {
-  print '<p><font class="smaller">Show</font> '.
-    $chunksz.' '._("items at once").'.</form>';
+  print '<p><font class="smaller">'.sprintf(_("Show %s items at once."), $chunksz).'</font></form>';
 }
 
 /* ==================================================
@@ -634,11 +632,12 @@ if ($result && $numrows > 0)
       $order_statement ='';
     }
   print '<a name="results"></a>';
-  # add the plural in brackets, so it looks a little nicer -- toddy 2004-02-29
-  print '<h3>'.$totalrows.' '._("matching item(s)").' '.$order_statement.'</h3>';
+  print '<h3>';
+  printf(ngettext("%d matching item", "%d matching items", $totalrows), $totalrows);
+  print ' '.$order_statement.'</h3>';
 
-  
-  print '<p>';
+
+  print '<p class="smaller">';
   if ($msort)
     {
       $url_alternate_sort = str_replace('msort=1','msort=0',$url).'&amp;order=#results';
@@ -650,14 +649,14 @@ if ($result && $numrows > 0)
   else
       {
         $url_alternate_sort = str_replace('msort=0','msort=1',$url).'&order=#results';
-        printf(_("Click a column heading to sort results (up or down), or %ssort by priority%s or %sreset sort%s. You can also %sactivate%s multicolumn sort."),
-          '<a href="'.$url.'&amp;order=priority#results"><b>', '</b></a>',
-          '<a href="'.$url.'&amp;order=#results"><b>', '</b></a>',
-	       '<a href="'.$url_alternate_sort.'"><b>', '</b></a>');
+        printf(_("Click a column heading to sort results (up or down), or %ssort by priority%s or %sreset sort%s. You can also %sactivate multicolumn sort%s."),
+          '<a href="'.$url.'&amp;order=priority#results">', '</a>',
+          '<a href="'.$url.'&amp;order=#results">', '</a>',
+	       '<a href="'.$url_alternate_sort.'">', '</a>');
       }
   print '</p>'."\n";
   show_item_list($result,$offset,$totalrows,$col_list,$lbl_list,$width_list,$url,false);
-  
+
   if ($digest)
     {
       print form_footer(_("Proceed to Digest next step"));
