@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: detail.php,v 1.34 2004/11/23 15:17:48 yeupou Exp $
+# $Id: detail.php,v 1.38 2005/03/20 19:05:46 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Yves Perrin <yves.perrin--at--cern.ch>
 #
 #
@@ -38,10 +38,7 @@ if (db_numrows($result) > 0)
   
   # Defines the item name, converting bugs to bug.
   # (Ideally, the artifact bugs should be named bug)
-  if (ARTIFACT == "bugs") 
-    { $item_name = "bug #".$item_id; }
-  else
-    { $item_name = ARTIFACT." #".$item_id; }
+  $item_name = utils_get_tracker_prefix(ARTIFACT)." #".$item_id;
   # Defines the item link
   $item_link = utils_link("?func=detailitem&item_id=".$item_id, $item_name);
 
@@ -77,7 +74,7 @@ if (db_numrows($result) > 0)
 
   print '<table cellpadding="0" width="100%">';
   print '<tr><td><font class="preinput">'._("Submitted by:").'</font>&nbsp;'.utils_user_link(user_getname(db_result($result,0,'submitted_by')),user_getrealname(db_result($result,0,'submitted_by'))).'</td>';
-  print '<td colspan="6" align="center" valign="top"><input type="submit" name="submit" value="'._("Submit Changes").'" class="bold"></td>';
+  print '<td colspan="6" align="center" valign="top"><span class="noprint"><input type="submit" name="submit" value="'._("Submit Changes").'" class="bold"></span></td>';
   print '</tr>';
   print '<tr><td><font class="preinput">'._("Submitted on:").'</font>&nbsp;'.format_date($sys_datefmt,db_result($result,0,'date')).'</td>';
   print '<td>&nbsp;</td>';
@@ -109,9 +106,11 @@ if (db_numrows($result) > 0)
 	  $field_value = db_result($result,0,$field_name);
 	  list($sz,) = trackers_data_get_display_size($field_name);
 
-	  $field_display = trackers_field_display($field_name,$group_id,$field_value,false,true,true);
 	  if ($field_name=='details') 
-	    $value = utils_make_links($field_display,$group_id);
+	    { $field_value = utils_make_links($field_value); }
+
+	  $field_display = trackers_field_display($field_name,$group_id,$field_value,false,true,true);
+
 
 	  if ($sz > $max_size) 
 	    {
@@ -136,18 +135,18 @@ if (db_numrows($result) > 0)
 
   # ################################ Shortcuts
 
-  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> details:"), $item_link).'</h2>';
+  print '<div class="noprint"><h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> details:"), $item_link).'</h2>';
   print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';  
   print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#history">'._("History").'</a><br />';
-  print '<p>&nbsp;</p>';
+  print '<p>&nbsp;</p></div>';
 
 
 # ################################ Comments 
 
-  print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3>';
+  print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3><div class="noprint">';
   printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"), 
 	  "<font class=\"italic\">artifact #nnn</font>",
 	  "<font class=\"italic\">artifact</font>",
@@ -164,7 +163,7 @@ if (db_numrows($result) > 0)
       print '</p>';
     }
 
-  print '<p>&nbsp;</p>';
+  print '<p>&nbsp;</p></div>';
 
   print show_item_details($item_id,$group_id);
 
@@ -174,7 +173,7 @@ if (db_numrows($result) > 0)
 
   print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
   
-  print '<font class="preinput"> '._("Attach File:").'</font><br />
+  print '<p class="noprint"><font class="preinput"> '._("Attach File:").'</font><br />
       &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
       <br />
       <font class="preinput">'._("File Description:").'</font><br />
@@ -188,11 +187,11 @@ if (db_numrows($result) > 0)
   # ################################ Mail notification
   
   print '<h3>'.html_anchor(_("Mail Notification Carbon-Copy List"), "cc").'</h3>';
-
   if (user_isloggedin()) 
     {
+      print '<p class="noprint">';
       printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
-      print '<p>
+      print '</p><p class="noprint">
 	   <font class="preinput">'._("Add an email address that should receive carbon copies of updates of this item:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="30"><br />
 	   <font class="preinput">'._("Comment:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255"><p>';
     }
@@ -215,7 +214,7 @@ if (db_numrows($result) > 0)
 
   #  Submit 
 
-  print '<p align="center">
+  print '<p align="center" class="noprint">
 	  <input type="submit" name="submit" class="bold" value="'._("Submit Changes").'">
 	  </form>
 	</p>';
