@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.35 2004/11/23 10:24:35 yeupou Exp $
+# $Id: index.php,v 1.37 2005/02/17 21:41:48 beuc Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -152,8 +152,38 @@ if ($group_id)
 				$changes);
 	      }
 
+	    # Originator Email:
+	    # "Email address of the person who submitted the item
+            # (if different from the submitter field, add address to CC list)"
+	    # Only apply this behavior if the field is present
+	    $oe_field_name = "originator_email";
+	    if  (($is_trackeradmin && trackers_data_is_showed_on_add_members($oe_field_name)) ||
+		 (!$is_trackeradmin && trackers_data_is_showed_on_add($oe_field_name)) ||
+		 (!user_isloggedin() && trackers_data_is_showed_on_add_nologin($oe_field_name)) ) 
+		    {
+                      # cannot be a registered user
+		      if (validate_email($_REQUEST{$oe_field_name}))
+			{
+			  # must be different from the submitter field
+			  $user=user_getid();
+			  $submitter_email = db_result(db_query("SELECT email FROM user WHERE user_id=".$user),
+			    0, 'email');
+			  if ($_REQUEST{$oe_field_name} != $submitter_email)
+			    {
+			      trackers_add_cc($item_id,
+					      $group_id,
+					      $_REQUEST{$oe_field_name},
+					      "Originator Email",
+					      $changes);
+			    }
+			}
+		      else
+			{
+			  fb(_("Originator E-mail is not valid, thus was not added to the Carbon-Copy list."), 1);
+			}
+		    }
 
-            # send an email to notify the user of the ite update
+            # send an email to notify the user of the item update
 	    list($additional_address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
 	    
 	    if ((trim($address) != "") && (trim($additional_address) != "")) 
@@ -250,11 +280,13 @@ if ($group_id)
             # Add new cc if any
 	    if ($add_cc)
 	      {
-		$changed |= trackers_add_cc($item_id,
-					    $group_id,
-					    $add_cc,
-					    $cc_comment, # 4
-					    $changes);
+		# No notification needs to be sent when a cc is added,
+		# it is irrelevant to the item itself
+		trackers_add_cc($item_id,
+				$group_id,
+				$add_cc,
+				$cc_comment, # 4
+				$changes);
 	      }
 	    
 	    if ($changed)
@@ -340,21 +372,26 @@ if ($group_id)
         # Add new cc if any, only accepted from logged in users.
 	if ($add_cc && user_isloggedin())
 	  {
-	    $changed |= trackers_add_cc($item_id,
-					$group_id,
-					$add_cc,
-					$cc_comment, # 4
-					$changes);
+            # No notification needs to be sent when a cc is added,
+            # it is irrelevant to the item itself
+	    trackers_add_cc($item_id,
+			    $group_id,
+			    $add_cc,
+			    $cc_comment, # 4
+			    $changes);
 	  }
 
-	list($additional_address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
-	if (($sendall == 1) && (trim($address) != "") && (trim($additional_address) != "")) 
+	if ($changed)
 	  {
-	    $address .= ", ";
+	    list($additional_address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
+	    if (($sendall == 1) && (trim($address) != "") && (trim($additional_address) != "")) 
+	      {
+		$address .= ", ";
+	      }
+	    $address .= $additional_address;
+	    trackers_mail_followup($item_id, $address,$changes);
 	  }
-	$address .= $additional_address;
-	trackers_mail_followup($item_id, $address,$changes);
-	
+	    
 	form_clean($form_id);
 	
 	include '../include/trackers_run/browse.php';
@@ -385,17 +422,19 @@ if ($group_id)
         #### Remove a person from the Cc: list of a bug
 	$changed = trackers_delete_cc($group_id,$item_id,$item_cc_id,$changes);
 
-	if ($changed)
-	  {
+	# Irrevelant: no need to warn people that someone got retired from the
+	# cc list.
+#	if ($changed)
+#	  {
              # see if we're supposed to send all modifications to an address
- 	     list($additional_address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
-	     if (($sendall == 1) && (trim($address) != "") && (trim($additional_address) != "")) 
-{
-	        $address .= ", ";
-             }
-	     $address .= $additional_address;
-             trackers_mail_followup($item_id, $address,$changes);
-	    }
+#	     list($additional_address, $sendall) = trackers_data_get_item_notification_info($item_id, ARTIFACT, 1);
+#	     if (($sendall == 1) && (trim($address) != "") && (trim($additional_address) != "")) 
+#{
+#	        $address .= ", ";
+#             }
+#	     $address .= $additional_address;
+#             trackers_mail_followup($item_id, $address,$changes);
+#	    }
 
           # unset previous settings and return to the item
 	  unset($depends_search, $reassign_change_project_search, $add_cc, $input_file, $changed, $vfl, $details); 
@@ -408,10 +447,11 @@ if ($group_id)
 	{
           ### Remove a dependancy
 
-	  $changed = trackers_delete_dependancy($group_id,
+	  $changed |= trackers_delete_dependancy($group_id,
 						$item_id,
 						$item_depends_on,
-						$item_depends_on_artifact);
+						$item_depends_on_artifact,
+                                                $changes);
 
 	  if ($changed)
 	    {
