@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: mod.php,v 1.17 2004/11/24 09:19:47 yeupou Exp $
+# $Id: mod.php,v 1.24 2005/03/21 14:54:40 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Yves Perrin <yves.perrin--at--cern.ch>
 #
 # This program is free software; you can redistribute it and/or
@@ -33,53 +33,50 @@ $max_size=40;
 
 $result=db_query($sql);
 
-if (db_numrows($result) > 0) 
+if (db_numrows($result) > 0)
 {
-  
+
   # Defines the item name, converting bugs to bug.
   # (Ideally, the artifact bugs should be named bug)
-  if (ARTIFACT == "bugs") 
-    { $item_name = "bug #".$item_id; }
-  else
-    { $item_name = ARTIFACT." #".$item_id; }
+  $item_name = utils_get_tracker_prefix(ARTIFACT)." #".$item_id;
   # Defines the item link
   $item_link = utils_link("?func=detailitem&item_id=".$item_id, $item_name);
 
-  # Check whether this item is private or not. If it is private, show only to 
+  # Check whether this item is private or not. If it is private, show only to
   # the submitter or to people that got the right to see private items
   unset($private_intro);
-  if (db_result($result,0,'privacy') == "2") 
+  if (db_result($result,0,'privacy') == "2")
     {
-      if (member_check_private(0, $group_id)) 
+      if (member_check_private(0, $group_id))
 	{
 	  # Nothing worth being mentioned
 	}
-      elseif (db_result($result,0,'submitted_by') == user_getid()) 
+      elseif (db_result($result,0,'submitted_by') == user_getid())
 	{
 	  $private_intro = _("This item is private. However, you are allowed to read it as you submitted it.");
 	}
-      else 
+      else
 	{
 	  exit_error(_("This item is private. You are not listed as member allowed to read private items."));
 	}
     }
 
-  # Prepare all the necessary fields in case the user wants to 
+  # Prepare all the necessary fields in case the user wants to
   # Create a new task based on this bug
-  
+
   # assigned_to is passed along
   $assigned_to = db_result($result,0,'assigned_to');
 
   # Check if hours is used. If so pass it along as well
-  if ( trackers_data_is_used('hours') ) 
+  if ( trackers_data_is_used('hours') )
     {
       $hours = db_result($result,0,'hours');
-    } 
-  else 
+    }
+  else
     {
       $hours = '';
     }
-    
+
   # Insert a reference to the originating bug in the task description
   $task_details = db_result($result,0,'details')."\n\nSee ".ARTIFACT." #$item_id\nhttp://".
      $GLOBALS['sys_default_domain']."/bugs/?func=detailitem&item_id=$item_id&group_id=$group_id";
@@ -96,23 +93,23 @@ if (db_numrows($result) > 0)
   # ################################ Check if the user have a specific role
 
   if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2', 1))
-    { 
+    {
       print help(_("You are both technician and manager for this tracker."),
 		 array(
-		       _("technician")=>_("can be assigned items, cannot change status or priority"),	       
+		       _("technician")=>_("can be assigned items, cannot change status or priority"),
 		       _("manager")=>_("fully manage the items")
 		       ));
 
     }
   elseif (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'1', 1))
-    { 
+    {
       print help(_("You are technician for this tracker."),
 		 array(
 		       _("technician")=>_("you can be assigned tracker's items, but you cannot reassign items, change their status or priority")
 		       ));
     }
   elseif (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'3', 1))
-    { 
+    {
       print help(_("You are manager for this tracker."),
 		 array(
 		       _("manager")=>_("you can fully manage the trackers items, including assigning items to technicians, reassign items over trackers and projects, changing priority and status of items")
@@ -133,33 +130,31 @@ print form_input("hidden", "item_id", $item_id);
     <table cellpadding="0" width="100%">
       <tr>
           <td class="preinput">'._("Submitted by:").'&nbsp;</td><td>'.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by'))).'</td>
-          <td colspan="6" align="center" valign="top"><input type="submit" name="submit" value="'._("Submit Changes and Browse Items").'" class="bold"></td>
+          <td colspan="6" align="center" valign="top"><span class="noprint"><input class="bold" type="submit" name="submit" value="'._("Submit Changes and Browse Items").'" ></span></td>
       </tr>
       <tr>
           <td class="preinput">'._("Submitted on:").'&nbsp;</td><td>'.format_date($sys_datefmt,db_result($result,0,'date')).'</td>
-          <td colspan="6" align="center" valign="top"><input type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></td>
+          <td colspan="6" align="center" valign="top"><input class="noprint" type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></td>
       </tr>';
-	  
+
   $field_per_linex2=2*$fields_per_line;
   print '<tr><td colspan="'.$fields_per_linex2.'">&nbsp</td></tr>';
 
   # Now display the variable part of the field list (depend on the project)
-    
-  $i=0;
-  while ($field_name = trackers_list_all_fields()) 
-    {
 
-      
-      # if the field is a special field (except summary and details) 
+  $i=0;
+  while ($field_name = trackers_list_all_fields())
+    {
+      # if the field is a special field (except summary and details)
       # or if not used by this project  then skip it.
       if ((!trackers_data_is_special($field_name) || $field_name=='summary' || $field_name=='details') &&
-	  trackers_data_is_used($field_name)) 
+	  trackers_data_is_used($field_name))
 	{
 	  # if the submitter was anonymous, print the originator email field
 	  if ($field_name != 'originator_email' ||
 	      ($field_name == 'originator_email' && db_result($result,0,'submitted_by') == '100'))
 	    {
-	      
+
 	  # display the bug field
 	  # if field size is greatest than max_size chars then force it to
 	  # appear alone on a new line or it won't fit in the page
@@ -167,7 +162,7 @@ print form_input("hidden", "item_id", $item_id);
 	  # Look for the field value in the database only if we missing
 	  # its values. If we already have a value, we are probably in
 	  # step 2 of a search on item/group (dependancy, reassignation).
-          
+
           # If nocache is set, we were explicetely asked to rely only
           # on database content
 	  if (!$$field_name || $nocache)
@@ -182,13 +177,13 @@ print form_input("hidden", "item_id", $item_id);
 	  # (if super_user, do nothing)
 	  if (!user_is_super_user())
 	    { $mbcheck = member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'1', 1); }
-	   
-	  if ($field_name =='details' || 
+
+	  if ($field_name =='details' ||
 	      $mbcheck && $field_name =='status_id' ||
 	      $mbcheck && $field_name =='assigned_to' ||
 	      $mbcheck && $field_name =='priority' ||
-	      $mbcheck && $field_name =='originator_email') 
-	    { 
+	      $mbcheck && $field_name =='originator_email')
+	    {
 	      dbg("field_name:$field_name is read-only, mbcheck_is_not_manager:$mbcheck_is_not_manager");
 	      $value = utils_make_links(trackers_field_display($field_name,$group_id,$field_value,false,false,true),$group_id);
 	    }
@@ -196,19 +191,21 @@ print form_input("hidden", "item_id", $item_id);
 	    {
               $value = trackers_field_display($field_name,$group_id,$field_value,false,false,"","","","","","",true);
 	    }
-	  $star = (trackers_data_is_empty_ok($field_name) ? '':'<font class="error"> *</font>');
- 
 
-	  if ($sz > $max_size) 
+
+	  $star = (trackers_data_is_empty_ok($field_name) ? '':'<font class="error"> *</font>');
+
+
+	  if ($sz > $max_size)
 	    {
 	      print "\n<tr>".
 		'<td valign="middle">'.$label.$star.'</td>'.
 		'<td valign="middle" colspan="'.(2*$fields_per_line-1).'">'.
-		$value.'</td>'.		      
+		$value.'</td>'.
 		"\n</tr>";
 	      $i=0;
-	    } 
-	  else 
+	    }
+	  else
 	    {
 	      print ($i % $fields_per_line ? '':"\n<tr>");
 	      print '<td valign="middle">'.$label.$star.'</td>'.
@@ -219,38 +216,38 @@ print form_input("hidden", "item_id", $item_id);
          }
 	}
     }
-      
+
   print '</table>';
   print '<p>&nbsp;</p>';
 
   # ################################ Shortcuts
 
-  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> details:"), $item_link).'</h2>';
-  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';  
+  print '<div class="noprint"><h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> details:"), $item_link).'</h2>';
+  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br />';
   if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3'))
     {
-      print '&nbsp;&nbsp;- <a href="#reassign">'._("Reassign this item").'</a><br />'; 
+      print '&nbsp;&nbsp;- <a href="#reassign">'._("Reassign this item").'</a><br />';
     }
 
   print '&nbsp;&nbsp;- <a href="#history">'._("History").'</a><br />';
-  print '<p>&nbsp;</p>';
-       
-  # ################################ Comments 
+  print '<p>&nbsp;<p></div>';
+
+  # ################################ Comments
 
   print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3>';
 
-  print '<table>
+  print '<table class="noprint">
           <tr><td class="preinput">'
     ._("Use a Canned Response:").'&nbsp;</td><td width="70%">';
 
   if ($canned_response == "!multiple!")
     {
-     
+
       $result_canned = trackers_data_get_canned_responses($group_id);
-      if (db_numrows($result_canned) > 0) 
+      if (db_numrows($result_canned) > 0)
 	{
 
 	  while ($canned = db_fetch_array($result_canned))
@@ -263,8 +260,7 @@ print form_input("hidden", "item_id", $item_id);
          }
       else
          {
-           print '<font class="warn">'._("Strangely enough, there is no canned
-response available.").'</font>';
+           print '<font class="warn">'._("Strangely enough, there is no canned response available.").'</font>';
          }
 
     }
@@ -282,15 +278,15 @@ response available.").'</font>';
   print trackers_field_box('comment_type_id',$comment_type_id,$group_id,'',true,'None');
   print '</td></tr></table>';
 
-  print '<p>';      
-  printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"), 
+  print '<p class="noprint">';
+  printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"),
 	  "<font class=\"italic\">artifact #nnn</font>",
 	  "<font class=\"italic\">artifact</font>",
 	  "<font class=\"italic\">support, bug, task, patch</font>",
 	  "<font class=\"italic\">nnn</font>");
 
-  print '<p>';      
-  print trackers_field_textarea('details',$details); 
+  print '<p class="noprint">';
+  print trackers_field_textarea('details',$details);
   print '<p>';
 
   print show_item_details($item_id,$group_id);
@@ -300,14 +296,14 @@ response available.").'</font>';
   # ################################ Attached Files
 
   print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
-  
-  print '<font class="preinput"> '._("Attach File:").'</font><br />
+
+  print '<p class="noprint"><font class="preinput"> '._("Attach File:").'</font><br />
       &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
       <br />
       <font class="preinput">'._("File Description:").'</font><br />
       &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
       </p><p>';
-	  
+
   show_item_attached_files($item_id,$group_id);
 
   print '</p>&nbsp;<p>';
@@ -315,10 +311,10 @@ response available.").'</font>';
   # ################################ Mail notification
 
   print '<h3>'.html_anchor(_("Mail Notification Carbon-Copy List"), "cc").'</h3>';
-  
+  print '<p class="noprint">';
   printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
 
-  print '<p><font class="preinput">'
+  print '</p><p class="noprint"><font class="preinput">'
     ._("Add an email address that should receive carbon copies of updates of this item:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" value="'.$add_cc.'">&nbsp;&nbsp;&nbsp;
         <br />
         <font class="preinput">'
@@ -331,11 +327,11 @@ response available.").'</font>';
   # ################################ Dependencies
 
   print '<h3>'.html_anchor(_("Dependencies"), "dependencies").'</h3>';
-  print '<font class="preinput">';
-  if (!$depends_search) 
+  print '<p class="noprint"><font class="preinput">';
+  if (!$depends_search)
     { print _("Search an item (to fill a dependancy against):"); }
-  else 
-    { 
+  else
+    {
       # Print a specific message if we are already at step 2 of filling
       # a dependency.
       print _("New search, in case the previous one was not satisfactory (to fill a dependancy against):");
@@ -343,17 +339,17 @@ response available.").'</font>';
 
   print '</font><br />
       &nbsp;&nbsp;&nbsp;<input type="text" name="depends_search" size="40" maxlength="255"><br />';
-  
-  
+
+
   function specific_depends_on_artifact ($art, $content)
-    { 
+    {
       # Function too trivial to generalized in usual includes.
-      if (ARTIFACT == $art) 
-	{ $checked = " selected=\"selected\""; }
-      print '<option value="'.$art.'"'.$checked.'>'.$content.'</option>'; 
+      if (ARTIFACT == $art)
+	{ $checked = ' selected="selected"'; }
+      print '<option value="'.$art.'"'.$checked.'>'.$content.'</option>';
       unset($checked);
     }
-      
+
   print '<font class="preinput">'._("Of:").'</font><br />
 &nbsp;&nbsp;&nbsp;<select name="depends_search_only_artifact">'
 .'<option value="all">'._("any Trackers").'</option>';
@@ -370,12 +366,12 @@ response available.").'</font>';
    .'<option value="notany" selected="selected">'._("this Project Only").'</option>
    </select>&nbsp;';
 
-  if (!$depends_search) 
-    { 
-      print '<input type="submit" name="submit" value="'._("Search").'">'; 
+  if (!$depends_search)
+    {
+      print '<input type="submit" name="submit" value="'._("Search").'">';
     }
-  else 
-    { 
+  else
+    {
       # Print a specific message if we are already at step 2 of filling
       # a dependency.
       print '<input type="submit" name="submit" value="'._("New search").'">';
@@ -383,7 +379,7 @@ response available.").'</font>';
 
   # Search results, if we are already at step 2 of filling
   if ($depends_search)
-    {     
+    {
       print '</p><p><font class="preinput">';
       printf (_("Please select a dependancy to add in the result of your search of '%s' in the database:"), $depends_search);
       print '</font>';
@@ -394,38 +390,38 @@ response available.").'</font>';
       # and put an exit to the report, just consider the search as a failure.
       if (strlen($depends_search) > 3)
 	{
-	  
-	  # Build the list of trackers to take account of.	  
+
+	  # Build the list of trackers to take account of.
 	  if ($depends_search_only_artifact == "all")
 	    { $artifacts = array("support", "bugs", "task", "patch"); }
-	  else 
+	  else
 	    { $artifacts = array($depends_search_only_artifact); }
-	  
+
 	  # Actually search on each asked trackers.
-	  while (list($num, $tracker) = each($artifacts)) 
-	    { 
-	      if ($depends_search_only_project == "notany") 
+	  while (list($num, $tracker) = each($artifacts))
+	    {
+	      if ($depends_search_only_project == "notany")
 		{ $GLOBALS['only_group_id'] = $group_id; }
- 
-              # Do not ask for all words, 
+
+              # Do not ask for all words,
               $GLOBALS['exact'] = 0;
 
 	      $result_search = search_run($depends_search, $tracker, 0);
 	      $success = db_numrows($result_search) + $success;
 
 	      # Print the result, if existing.
-	      if (db_numrows($result_search) != 0) 
+	      if (db_numrows($result_search) != 0)
 		{
 		  while (list($res_id, $res_summary, $res_date, $res_user, $res_group)  = db_fetch_array($result_search))
 		    {
 		      # Avoid item depending on itself.
 		      if ($res_id != $item_id || $tracker != ARTIFACT)
-			{			  
+			{
 			  # Right now only print id, summary and group.
 			  # We may change that depending on users feedback.
 			  print '<br />';
 			  print '&nbsp;&nbsp;&nbsp;<input type="checkbox" name="dependent_on_'.$tracker.'[]" value="'.$res_id.'">'.$tracker.' #'.$res_id._(': ').$res_summary;
-                          if (group_getname($res_group)) 
+                          if (group_getname($res_group))
                             { print ', '._("group").' '.group_getname($res_group); }
 			}
 		    }
@@ -438,36 +434,35 @@ response available.").'</font>';
 	  print _("None found. Please note that only search words of more than three characters are valid.");
 	  print '</font>';
 	}
-      
+
     }
 
 
-  print '<p></p>';
+  print '</p><p>';
 
 
   print show_item_dependency($item_id);
 
-  print '<p></p>';
+  print '</p><p>';
 
   print show_dependent_item($item_id);
 
-  print '<p>&nbsp;</p>';
+  print '</p><p>&nbsp;</p>';
 
   # ################################ Reassign an item, if manager of the tracker
-
   if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3'))
     {
-      print '<h3>'.html_anchor(_("Reassign this item"), "reassign").'</h3>';
-        
-      print '<p><font class="preinput">'
+      print '<h3 class="noprint">'.html_anchor(_("Reassign this item"), "reassign").'</h3>';
+
+      print '<p class="noprint"><font class="preinput">'
 	._("Move to the:").'</font><br />&nbsp;&nbsp;&nbsp;';
 
       function specific_reassign_artifact ($art, $content)
 	{
 	  # Function too trivial to generalized in usual includes.
-	  if (!$GLOBALS[reassign_change_artifact] && ARTIFACT == $art || $GLOBALS[reassign_change_artifact] == $art) 
-	    { $checked = " selected"; }
-	  print '<option value="'.$art.'"'.$checked.'>'.$content.'</option>'; 
+	  if (!$GLOBALS[reassign_change_artifact] && ARTIFACT == $art || $GLOBALS[reassign_change_artifact] == $art)
+	    { $checked = ' selected="selected"'; }
+	  print '<option value="'.$art.'"'.$checked.'>'.$content.'</option>';
 	  unset($checked);
 	}
       print '<select name="reassign_change_artifact">';
@@ -480,31 +475,31 @@ response available.").'</font>';
       print '<br /><br />
         <font class="preinput">';
 
-      if (!$reassign_change_project_search) 
+      if (!$reassign_change_project_search)
 	{  print _("Move to the project:"); }
-      else 
-	{ 
+      else
+	{
 	  # Print a specific message if we are already at step 2 of
 	  # reassignation to another project.
 	  print _("New search, in case the previous one was not satisfactory (to reassign the item to another project):");
 	}
 
       print '</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="reassign_change_project_search" size="40" maxlength="255">';
-      if (!$reassign_change_project_search) 
-	{ 
-	  print ' <input type="submit" name="submit" value="'._("Search").'">'; 
+      if (!$reassign_change_project_search)
+	{
+	  print ' <input type="submit" name="submit" value="'._("Search").'">';
 	}
-      else 
-	{ 
+      else
+	{
 	  # Print a specific message if we are already at step 2 of filling
 	  # a ressign.
 	  print ' <input type="submit" name="submit" value="'._("New search").'">';
 	}
-      
+
 
       # Search results, if we are already at step 2 of filling
       if ($reassign_change_project_search)
-	{     
+	{
 	  print '</p><p><font class="preinput">';
 	  printf (_("To which project this bug should be reassigned to? This is the result of your search of '%s' in the database:"), $reassign_change_project_search);
 	  print '</font>';
@@ -512,51 +507,51 @@ response available.").'</font>';
 	  # Print a null-option, someone may change his mine without having
 	  # to use the back button of his browser.
 	  print '<br />&nbsp;&nbsp;&nbsp;<input type="radio" name="reassign_change_project" value="0" checked> '._("Do not reassign to another project.");
-	  
+
 	  unset($success);
 	  $result_search = search_run($reassign_change_project_search, "soft", 0);
 	  $success = db_numrows($result_search);
-	  
+
 	  # Print the result, if existing.
-	  if (db_numrows($result_search) != 0) 
+	  if (db_numrows($result_search) != 0)
 	    {
 	      while (list($res_group_name, $res_unix_group_name, $res_group_id)  = db_fetch_array($result_search))
 		{
 		  # Not reassigning to itself.
 		  if ($res_unix_group_name != $group_name)
-		    {			  
+		    {
 		      print '<br />';
 		      print '&nbsp;&nbsp;&nbsp;<input type="radio" name="reassign_change_project" value="'.$res_unix_group_name.'"> ['.$res_unix_group_name.', #'.$res_group_id.'] '.$res_group_name;
 		    }
 		}
 	    }
-	  
+
 	  if (!$success)
 	    {
 	      print '<br /><font class="warn">';
 	      print _("None found. Please note that only search words of more than three characters are valid.");
 	      print '</font>';
 	    }
-	  
-	}  
+
+	}
     }
 
 
 
-  #  ################################ Submit 
- 
+  #  ################################ Submit
+
   print '<p>&nbsp;</p>';
- 
-  print '<p align="center"><input type="submit" name="submit" class="bold" value="'._("Submit Changes and Browse Items").'"> <input type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></form><p>';
-  
-  
-  # ################################ History  
+
+  print '<p align="center" class="noprint"><input type="submit" name="submit" class="bold" value="'._("Submit Changes and Browse Items").'"> <input type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></form><p>';
+
+
+  # ################################ History
   # May require in the future to think about only showing recent changes.
 
   print '<p>&nbsp;</p><p>&nbsp;</p>';
   print show_item_history($item_id,$group_id);
 
-} 
+}
 
 trackers_footer(array());
 
