@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: user_home.php,v 1.34 2004/09/22 08:11:51 yeupou Exp $
+# $Id: user_home.php,v 1.35 2004/11/22 08:25:50 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2001 (c) Free Software Foundation
@@ -133,7 +133,7 @@ print '
 <tr valign="top">
 	<td>'
 	._("User ID:").' </td>
-	<td><b>'.db_result($res_user,0,'user_id').'</b></td>
+	<td><b>#'.db_result($res_user,0,'user_id').'</b></td>
 </tr>
 <tr valign="top">
 	<td>'._("Email Address:").' </td>
