@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: utils.php,v 1.65 2004/11/22 08:25:50 yeupou Exp $
+# $Id: utils.php,v 1.68 2005/03/20 14:51:25 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>,
+#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>,
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -72,9 +72,9 @@ function utils_link ($url, $title, $defaultclass=0, $available=1, $help=0)
 
   $return = '<a href="'.$url.'"';
 
-  if ($defaultclass) 
+  if ($defaultclass)
     { $return .= ' class="'.$defaultclass.'"'; }
-  if ($help) 
+  if ($help)
     { $return .= ' title="'.$help.'"'; }
   $return .= '>'.$title.'</a>';
   return $return;
@@ -392,9 +392,10 @@ function utils_make_links ($data='',$group_id = 0)
       # english so we always get the links found without having a regexp
       # including every possible language.
       $line = eregi_replace("(bugs|bug)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."bugs/?func=detailitem&amp;item_id=\\2\" class=\"italic\">bug&nbsp;#\\2</a>", $line);
-      $line = eregi_replace("(support|sr)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."support/?func=detailitem&amp;item_id=\\2\" class=\"italic\">support&nbsp;#\\2</a>", $line);
+      $line = eregi_replace("(support|sr)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."support/?func=detailitem&amp;item_id=\\2\" class=\"italic\">sr&nbsp;#\\2</a>", $line);
       $line = eregi_replace("task[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."task/?func=detailitem&amp;item_id=\\1\" class=\"italic\">task&nbsp;#\\1</a>", $line);
       $line = eregi_replace("patch[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."patch/?func=detailitem&amp;item_id=\\1\" class=\"italic\">patch&nbsp;#\\1</a>", $line);
+      $line = eregi_replace("comment[ ]?#([0-9]+)", '<a href="#comment\\1">comment&nbsp;#\\1</a>', $line);
 
 
 
@@ -467,7 +468,7 @@ function show_priority_colors_key()
     {
       print '<span class="'.utils_get_priority_color($i).'">&nbsp;'.$i.'&nbsp;</span>'."\n";
     }
-  
+
   print '<br />';
   print _("Closed Items Priority Colors:")."<br />&nbsp;&nbsp;&nbsp;\n";
 
@@ -483,6 +484,25 @@ function get_priority_color ($index, $closed="")
 { return utils_get_priority_color($index, $closed); }
 
 
+function utils_get_tracker_icon ($tracker)
+{
+  if ($tracker == "bugs")
+    { return "bug"; }
+  if ($tracker == "support")
+    { return "help"; }
+  return $tracker;
+}
+
+function utils_get_tracker_prefix ($tracker)
+{
+  if ($tracker == "bugs")
+    { return "bug"; }
+  if ($tracker == "support")
+    { return "sr"; }
+  return $tracker; 
+}
+
+
 function utils_get_priority_color ($index, $closed="")
 {
   global $bgpri;
@@ -902,8 +922,8 @@ function fb ($msg, $error=0)
   # First letter capitalized, that's all
   $msg = strtoupper(substr($msg, 0, 1)).strtolower(substr($msg, 1, strlen($msg)));
 
-  if ($GLOBALS['sys_debug_on']) 
-    { 
+  if ($GLOBALS['sys_debug_on'])
+    {
       $msg .= ' [#'.$GLOBALS['feedback_count'].']';
       dbg("Add feedback #".$GLOBALS['feedback_count']);
     }
@@ -930,7 +950,7 @@ function fb_dberror()
 # fb function to be used about database error when context of error is obvious
 function fb_dbsuccess()
 {
-  fb(_("Database succesfully updated"));
+  fb(_("Database successfully updated"));
 }
 
 # alias
