@@ -2,10 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: groups.php,v 1.11 2004/11/22 08:25:50 yeupou Exp $
+# $Id: groups.php,v 1.17 2005/03/21 13:53:43 yeupou Exp $
 #
-#  Copyright 2003-2004 (c) Frederik Orellana <frederik.orellana@cern.ch>
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2005 (c) Frederik Orellana <frederik.orellana--cern.ch>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
 
 require "../include/pre.php";
 require_directory("search");
+require_directory("trackers");
 
 # ###### get global user and group vars
 
@@ -33,6 +34,53 @@ $sys_pending_user_permissions = $GLOBALS['sys_pending_user_permissions'];
 $register_error=0;
 
 
+$sql = "SELECT groups.group_name,"
+. "groups.group_id,"
+. "groups.unix_group_name,"
+. "groups.status,"
+. "user_group.admin_flags, "
+. "group_history.date "
+. "FROM groups,user_group,group_history "
+. "WHERE groups.group_id=user_group.group_id "
+. "AND user_group.user_id='".user_getid()."' "
+. "AND groups.status='A' "
+. "AND (group_history.field_name='Added User' OR group_history.field_name='Approved User' OR user_group.admin_flags='P')"
+. "AND group_history.group_id=user_group.group_id " 
+. "AND group_history.old_value='".user_getname()."' " 
+. "GROUP BY groups.unix_group_name "
+. "ORDER BY groups.unix_group_name";
+
+$result = db_query($sql);
+$rows = db_numrows($result);
+
+# Alternative sql that do not use group_history, just in case this history
+# would be flawed (history usage has been inconsistent over Savane history)
+$sql_without_history = "SELECT groups.group_name,"
+. "groups.group_id,"
+. "groups.unix_group_name,"
+. "groups.status,"
+. "user_group.admin_flags "
+. "FROM groups,user_group "
+. "WHERE groups.group_id=user_group.group_id "
+. "AND user_group.user_id='".user_getid()."' "
+. "AND groups.status='A' "
+. "GROUP BY groups.unix_group_name "
+. "ORDER BY groups.unix_group_name";
+
+$result_without_history = db_query($sql_without_history);
+$rows_without_history = db_numrows($result_without_history);
+
+if ($rows_without_history != $rows)
+{
+  # If number of rows differ, assume that history is flawed. Print a
+  # feedback incitating to fix the installation and override flawed result
+  fb(_("Groups history appears to be flawed. This is a site installation problem. Please report the incident to administrators, asking them to get in touch with their Savane supplier."), 1);
+  $result = $result_without_history;
+  $rows = $rows_without_history;
+}
+
+
+
 # ###### function send_pending_user_email($group_id, $user_id, $user_message)
 # ###### sends an email to group admins when a user joins group
 
@@ -49,7 +97,7 @@ function send_pending_user_email($group_id, $user_id, $user_message)
 
   $row_grp = db_fetch_array($res_grp);
 
-  $res_admins = db_query("SELECT user.user_name,user.email FROM user,user_group WHERE "
+  $res_admins = db_query("SELECT user.user_name FROM user,user_group WHERE "
 			 . "user.user_id=user_group.user_id AND user_group.group_id='$group_id' AND "
 			 . "user_group.admin_flags='A'");
 
@@ -62,7 +110,7 @@ function send_pending_user_email($group_id, $user_id, $user_message)
   $admin_list = '';
   while ($row_admins = db_fetch_array($res_admins))
     {
-      $admin_list .= ($admin_list ? ',':'').$row_admins['email'];
+      $admin_list .= ($admin_list ? ',':'').$row_admins['user_name'];
     }
 
   $message = approval_user_gen_email($row_grp['group_name'],
@@ -73,7 +121,7 @@ function send_pending_user_email($group_id, $user_id, $user_message)
 				     user_getemail($user_id),
 				     $user_message);
 
-  sendmail_mail($GLOBALS['sys_email_adress'],
+  sendmail_mail(user_getname(),
 		$admin_list,
 		sprintf(_("Membership request for group %s"), $row_grp['group_name']),
 		$message,
@@ -97,7 +145,7 @@ function update_tbl()
 
   utils_get_content("my/request_for_inclusion");
 
-  $result = db_query("SELECT group_id FROM groups WHERE status='A' AND
+  $result_upd = db_query("SELECT group_id FROM groups WHERE status='A' AND
             is_public='1' ORDER BY group_id");
 
   if ($GLOBALS["update"])
@@ -107,7 +155,7 @@ function update_tbl()
       if (!form_check($form_id))
 	{ return 0; }
 	    
-      while ($val = db_fetch_array($result))
+      while ($val = db_fetch_array($result_upd))
 	{
 	  if($GLOBALS["form_groups_$val[group_id]"])
 	    {
@@ -145,35 +193,107 @@ function update_tbl()
 
 update_tbl();
 
+# Some action to be done ?
+if ($func)
+{
+  if ($func == "delwatchee")
+    {
+# Stop watching another user
+      $result_upd = trackers_data_delete_watchees(user_getid(),$watchee_id,$group_id);
+      if (!$result_upd)
+	{
+	  fb(_("Unable to remove user from the watched users list, probably a broken URL"));
+	}
+      
+    }
+  
+  if ($func == "addwatchee")
+    {
+# Stop watching another user
+      $result_upd = trackers_data_add_watchees(user_getid(),$watchee_id,$group_id);
+      if (!$result_upd)
+	{
+	  fb(_("Unable to add user in the watched users list, probably a broken URL"));
+	}
+      
+    }
+}
+
 
 # page header
 site_user_header(array('toptab'=>'mygroups'));
 
 # we get site-specific content
-utils_get_content("account/change_groups_intro");
+utils_get_content("my/groups");
 print "<br /><br />\n\n";
 
-$result = db_query("SELECT groups.group_name,"
-		   . "groups.group_id,"
-		   . "groups.unix_group_name,"
-		   . "groups.status,"
-		   . "user_group.admin_flags "
-		   . "FROM groups,user_group "
-		   . "WHERE groups.group_id=user_group.group_id "
-		   . "AND user_group.user_id='". user_getid() ."' "
-		   . "AND groups.status='A'");
-$rows=db_numrows($result);
-
 
 ################ RIGHT PART ###########################
 
-print html_splitpage(1);
+print html_splitpage(1);  # Watching other users.
+
+print $HTML->box_top(_("Watched Partners"));
+
+$result_w = trackers_data_get_watchees(user_getid());
+$rows_w=db_numrows($result_w);
+
+if (!$result_w || $rows_w < 1)
+    {
+      print _("I am not watching any partners.");
+      print '<p>'._("Watching a partner (receiving a copy of all the notification sent to him) permits to be his backup when he is away from the office, or to do QA to all his/her activities on a project.");
+      print '</p><p>'._("To watch someone, click 'Watch Partner' in any project memberlist page (membership to that project is required, indeed).");
+      print '<br />&nbsp;';
+      print db_error();
+    }
+else
+    {
+      print '<table>';
+      for ($i=0; $i<$rows_w; $i++)
+	{
+	  print '<tr class="'.utils_get_alt_row_color($i).'"><td width="99%"><font class="bold">'.
+	    utils_user_link(user_getname(db_result($result_w, $i, 'watchee_id')), user_getrealname(db_result($result_w, $i, 'watchee_id'))).
+	    '</font> <font class="smaller">['.group_getname(db_result($result_w, $i, 'group_id')).']'.
+	    '</font>';
+
+	  print '</td>'.
+	    '<td><a href="'.$PHPSELF.'?func=delwatchee&amp;group_id='.db_result($result_w,$i,'group_id').'&amp;watchee_id='.db_result($result_w, $i, 'watchee_id').
+	    '" onClick="return confirm(\''._("Stop watching this user?").'\')">'.
+	    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Stop watching this user?").'" /></a></td></tr>';
+	}
+      print '</table>';
+
+    }
+
+  $result_w = trackers_data_get_watchers(user_getid());
+  $arr_watchers = array();
+  while ($row_watcher = db_fetch_array($result_w))
+    {
+      $watchers .= utils_user_link(user_getname($row_watcher['user_id']), user_getrealname($row_watcher['user_id'])).'</font> <font class="smaller">['.group_getname($row_watcher['group_id']).']</font>, ';
+    }
+
+  if ($watchers)
+    {
+      $watchers = substr($watchers,0,-2); # remove extra comma at the end
+      $watchers .= ".";
+
+      print '<p>';
+      printf (_("My own notifications are currently watched by: %s"),$watchers);
+      print '</p>';
+    }
+  else
+    {
+      print '<p>'._("Nobody is currently watching my own notifications.").'</p>';
+    }
+
+print $HTML->box_bottom();
+
+print "<br />\n";
 
 print $HTML->box_top(_("Request for Inclusion"),'',1);
 
 print '<div class="boxitem">'._("Search a Group")."\n";
   print '<p class="text">';
-print _("If there is a project - or several - I would like to be member of, to be able to fully contribute, it is possible to search his/their name(s) in the whole group database with the following search tool. A list of groups will be generated, depending on the word(s) typed in this form.")."\n";
+print _("If there is a project - or several - you would like to be member of, to be able to fully contribute, it is possible to search his/their name(s) in the whole group database with the following search tool. A list of groups will be generated, depending on the word(s) typed in this form.")."\n";
 print '</p>';
 
 print '
@@ -237,45 +357,8 @@ if ($words)
   print '</div><!-- end boxitemalt -->';
 }
 
-
-
 print $HTML->box_bottom(1);
 
-print "<br />\n";
-
-/*
-     Projects the user requested to be member of
-*/
-
-print $HTML->box_top(_("Request for Inclusion Waiting For Approval"),'',1);
-
-unset($content);
-for ($i=0; $i<$rows; $i++)
-{
-  if (db_result($result,$i,'admin_flags') == 'P')
-    {
-      
-      $content .= '<li class="'.utils_get_alt_row_color($j).'">';
-      $content .= '<span class="trash"><a href="../my/rmproject.php?group_id='. db_result($result,$i,'group_id').'">'.
-	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Discard this request?").'" /></a></span>'; 
-
-      $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />&nbsp;</li>';
-      $exists=1;
-
-    }
-}
-
-if (!$exists)
-{
-  print _("None Found");
-}
-else
-{
-  print '<ul class="boxli">'.$content.'</ul>';
-}
-unset($exists);
-
-print $HTML->box_bottom(1);
 
 print html_splitpage(2);
 
@@ -306,11 +389,18 @@ else
       if (db_result($result,$i,'admin_flags') == 'A')
 	{
 	  $content .= '<li class="'.utils_get_alt_row_color($j).'">';
-	  $content .= '<span class="trash"><a href="../my/rmproject.php?group_id='. db_result($result,$i,'group_id').
+	  $content .= '<span class="trash"><a href="../my/quitproject.php?quitting_group_id='. db_result($result,$i,'group_id').
 	    '">'.
-	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Quit this project?").'" /></a><br /></span>'; 
+	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" alt="'._("Quit this project?").'" /></a><br /></span>'; 
 
-	  $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />&nbsp;</li>';
+	  $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />';
+	  if (db_result($result,$i,'date'))
+	    {
+	      # If the group history is flawed (site install problem), the 
+	      # date may be unavailable
+	      $content .= '<font class="smaller">'.sprintf(_("Member since %s"), strftime('%B %Y',db_result($result,$i,'date'))).'</font>';
+	    }
+	  $content .= '</li>';
 	  $exists=1;
 	  $j++;
 	}
@@ -341,13 +431,19 @@ else
     {
       if (db_result($result,$i,'admin_flags') == '')
 	{
-
 	  $content .= '<li class="'.utils_get_alt_row_color($j).'">';
-	  $content .= '<span class="trash"><a href="../my/rmproject.php?group_id='. db_result($result,$i,'group_id').
+	  $content .= '<span class="trash"><a href="../my/quitproject.php?quitting_group_id='. db_result($result,$i,'group_id').
 	    '">'.
-	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Quit this project?").'" /></a></span>'; 
+	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" alt="'._("Quit this project?").'" /></a></span>'; 
 
-	  $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />&nbsp;</li>';
+	  $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />';
+	  if (db_result($result,$i,'date'))
+	    {
+	      # If the group history is flawed (site install problem), the 
+	      # date may be unavailable
+	      $content .= '<font class="smaller">'.sprintf(_("Member since %s"), strftime('%B %Y',db_result($result,$i,'date'))).'</font>';
+	    }
+	  $content .= '</li>';
 	  $exists=1;
 	  $j++;
 	}
@@ -366,6 +462,42 @@ else
   print $HTML->box_bottom(1);
  
 
+print "<br />\n";
+
+/*
+     Projects the user requested to be member of
+*/
+
+print $HTML->box_top(_("Request for Inclusion Waiting For Approval"),'',1);
+
+unset($content);
+
+for ($i=0; $i<$rows; $i++)
+{
+  if (db_result($result,$i,'admin_flags') == 'P')
+    {
+      $content .= '<li class="'.utils_get_alt_row_color($j).'">';
+      $content .= '<span class="trash"><a href="../my/quitproject.php?quitting_group_id='. db_result($result,$i,'group_id').'&amp;pending=1">'.
+	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" alt="'._("Discard this request?").'" /></a></span>'; 
+
+      $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />&nbsp;</li>';
+      $exists=1;
+
+    }
+}
+
+if (!$exists)
+{
+  print _("None Found");
+}
+else
+{
+  print '<ul class="boxli">'.$content.'</ul>';
+}
+unset($exists);
+
+print $HTML->box_bottom(1);
+
 }
 
 print html_splitpage(3);
