@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: viewjob.php,v 1.26 2004/09/22 08:11:52 yeupou Exp $
+# $Id: viewjob.php,v 1.27 2004/10/30 02:18:40 sonicmctails Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -49,24 +49,21 @@ if ($group_id && $job_id)
   $result=db_query($sql);
   if (!$result || db_numrows($result) < 1)
     {
-      echo db_error();
+      print db_error();
       fb(_("POSTING fetch FAILED"));
-      echo '<h2>'._("No Such Posting For This Project").'</h2>';
+      print '<h2>'._("No Such Posting For This Project").'</h2>';
     }
   else
     {
       $project=project_get_object($group_id);
-      echo '
-		<h2>';
-      echo db_result($result,0,'category_name');
+      print '
+		<h2 class=toptitle>';
+      print db_result($result,0,'category_name');
 
-      echo  ' '._("wanted for").' <a href="'.$GLOBALS['sys_home'].'project/?group_id='. $group_id .'">'. db_result($result,0,'group_name') .'</a></h2>
-		<b>'
-	._("Origin:").'</b> <A HREF="'.$GLOBALS['sys_home'].'users/'. db_result($result,0,'user_name') .'">'. db_result($result,0,'user_name').'</a><br />
-                <b>'
-	._("Date:").'</b> '. format_date($sys_datefmt,db_result($result,0,'date')) .'<br />
-                <b>'
-	._("Status").':</b> '. db_result($result,0,'status_name');
+      print  ' '._("wanted for").' <a href="'.$GLOBALS['sys_home'].'project/?group_id='. $group_id .'">'. db_result($result,0,'group_name') .'</a></h2>'.
+	'<font class=preinput>'._("Submitted By:").'</font></b> <A HREF="'.$GLOBALS['sys_home'].'users/'. db_result($result,0,'user_name') .'">'. db_result($result,0,'user_name').'</a><br />'.
+	'<font class=preinput>'._("Date:").'</font>'. format_date($sys_datefmt,db_result($result,0,'date')) .'<br />'.
+	'<font class=preinput>'._("Status").':</font> '. db_result($result,0,'status_name');
 
 
 
@@ -86,7 +83,7 @@ if ($group_id && $job_id)
 	    }
 	}
       $license = $project->getLicense();
-      print '<p><b>'._("License").'</b>: ';
+      print '<p><font class=preinput>'._("License").'</font> ';
       if ($LICENSE_URL[$license] != "0")
 	{
 	  print '<a href="'.$LICENSE_URL[$license].'" target="_blank">'.$LICENSE[$license].'</a>';
@@ -96,15 +93,14 @@ if ($group_id && $job_id)
 	  print $LICENSE[$license];
 	}
       $devel_status = $project->getDevelStatus();
-      print '<br /><b>'
-	._("Development Status").'</b>: '.$DEVEL_STATUS[$devel_status];
+      print '<font class=preinput><br />'
+	._("Development Status").'</font>: '.$DEVEL_STATUS[$devel_status];
 
-      print '<p><b>'._("Details (job description, contact...):").'</b><br />
-			'. utils_make_links(nl2br(db_result($result,0,'description'))) .'
-		<p><h3>'
-	._("Required Skills:").'</h3>';
+      print '<p><font class=preinput>'._("Details (job description, contact...):").'</font></b><br />
+			'. utils_make_links(nl2br(db_result($result,0,'description'))).'<p><h3>'
+		._("Required Skills:").'</h3>';
       #now show the list of desired skills
-      echo '<p>'.people_show_job_inventory($job_id);
+      print '<p>'.people_show_job_inventory($job_id);
     }
 
   site_project_footer(array());
