@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: editgroupfeatures.php,v 1.6 2004/11/22 08:25:51 yeupou Exp $
+# $Id: editgroupfeatures.php,v 1.7 2005/03/20 11:47:20 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -55,6 +55,10 @@ if ($update)
     { $use_task=0; }
   if (!$use_cvs) 
     { $use_cvs=0; }
+  if (!$use_arch) 
+    { $use_arch=0; }
+  if (!$use_svn) 
+    { $use_svn=0; }
   if (!$use_news) 
     { $use_news=0; }
   if (!$use_news) 
@@ -71,6 +75,8 @@ if ($update)
 		 "use_forum",
 		 "use_task",
 		 "use_cvs",
+		 "use_arch",
+		 "use_svn",
 		 "use_news",
 		 "use_support",
 		 "use_download",
@@ -85,7 +91,10 @@ if ($update)
 		 "url_cvs",
 		 "url_cvs_viewcvs",
 		 "url_cvs_viewcvs_homepage",
-		 "url_cvs",
+		 "url_arch",
+		 "url_arch_viewcvs",
+		 "url_svn",
+		 "url_svn_viewcvs",
 		 "url_support",
 		 "dir_download",
 		 "url_extralink_documentation");
@@ -192,6 +201,8 @@ function specific_line ($artifact, $explanation, $use, $increment=1)
       if ($artifact == "homepage" ||
 	  $artifact == "download" ||
 	  $artifact == "cvs_viewcvs" ||
+	  $artifact == "arch_viewcvs" ||
+	  $artifact == "svn_viewcvs" ||
 	  preg_match("/viewcvs/", $artifact) ||
 	  preg_match("/extralink/", $artifact))
 	{
@@ -220,14 +231,17 @@ print '
 
 $title_arr=array();
 $title_arr[]=_("Feature, Artifact");
-$title_arr[]=_("Show it in the Menu?");
+$title_arr[]=_("Activated?");
 $title_arr[]=_("Standard Address");
 $title_arr[]=_("Alternative Address");
 
 print html_build_list_table_top ($title_arr);
 
 if ($project->CanUse("homepage"))
-{ specific_line("homepage", _("Project Homepage"), $project->Uses("homepage")); }
+{ 
+  specific_line("homepage", _("Homepage"), $project->Uses("homepage")); 
+  specific_line("cvs_viewcvs_homepage", _("Homepage Source Code Web Browsing"), 0, 0); 
+}
 
 if ($project->CanModifyUrl("extralink_documentation"))
 { specific_line("extralink_documentation", _("Documentation"), $project->Uses("extralink_documentation")); }
@@ -266,13 +280,20 @@ if ($project->CanUse("mailing_list"))
 if ($project->CanUse("cvs") || $project->CanUse("homepage"))
 { 
   specific_line("cvs", _("CVS"), $project->Uses("cvs")); 
-  specific_line("cvs_viewcvs", _("Viewcvs (www cvs browser)"), 0, 0); 
-  # FIXME: test should be made upon the nature of the homepage dir
-  #  if ($project->())
-  #  {
-      specific_line("cvs_viewcvs_homepage", _("Homepage viewcvs (www cvs browser)"), 0, 0); 
-      #  }
+  specific_line("cvs_viewcvs", _("CVS Web Browsing"), 0, 0); 
 }
+if ($project->CanUse("arch"))
+{ 
+  specific_line("arch", _("GNU Arch"), $project->Uses("arch")); 
+  specific_line("arch_viewcvs", _("Arch Web Browsing"), 0, 0); 
+}
+
+if ($project->CanUse("svn"))
+{ 
+  specific_line("svn", _("Subversion"), $project->Uses("svn")); 
+  specific_line("svn_viewcvs", _("Subversion Web Browsing"), 0, 0); 
+}
+
 
 if ($project->CanUse("bug"))
 { specific_line("bugs", _("Bugs Tracker"), $project->Uses("bugs")); }
