@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sendmessage.php,v 1.27 2004/10/30 02:18:40 sonicmctails Exp $
+# $Id: sendmessage.php,v 1.28 2005/03/20 15:13:06 yeupou Exp $
 # 
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundatio
@@ -46,7 +46,7 @@ if (user_isloggedin())
       $result=db_query("SELECT email,user_name FROM user WHERE user_id='$touser'");
       if (!$result || db_numrows($result) < 1) 
 	{
-	  exit_error('Error',_('That user does not exist'));
+	  exit_error(_('That user does not exist'));
 	}
     } 
   else
@@ -66,7 +66,7 @@ if (user_isloggedin())
       else 
 	{
 	  # Let sendmail_mail() figuring out real email addresses
-	  sendmail_mail($fromuser, $touser, $subject, $body);
+	  sendmail_mail($fromuser, $touser, $subject, stripslashes($body));
 	  $HTML->header(array('title'=>_('Message Sent')));
 	  print html_feedback_top($GLOBALS['feedback']);
 	  $HTML->footer(array());
